@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_hpi.cpp,v 1.35 2008/07/18 20:06:10 fredg Exp $
+//      $Id: cae_hpi.cpp,v 1.38 2011/05/18 15:25:32 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -54,6 +54,24 @@ void MainObject::hpiFree()
 }
 
 
+QString MainObject::hpiVersion()
+{
+#ifdef HPI
+  if(sound_card==NULL) {
+    return QString("not active");
+  }
+  RDHPIInformation *info=sound_card->hpiInformation(0);
+  if(info->hpiVersion()==0) {
+    return QString("not active");
+  }
+  return QString().sprintf("%d.%02d.%02d",info->hpiMajorVersion(),
+			   info->hpiMinorVersion(),info->hpiPointVersion());
+#else
+  return QString("not enabled");
+#endif  // HPI
+}
+
+
 bool MainObject::hpiLoadPlayback(int card,QString wavename,int *stream)
 {
 #ifdef HPI
@@ -215,7 +233,7 @@ bool MainObject::hpiLoadRecord(int card,int stream,int coding,int chans,
 }
 
 
-bool MainObject::hpiUnloadRecord(int card,int stream)
+bool MainObject::hpiUnloadRecord(int card,int stream,unsigned *len)
 {
 #ifdef HPI
   if(record[card][stream]==NULL) {
@@ -225,6 +243,7 @@ bool MainObject::hpiUnloadRecord(int card,int stream)
     record[card][stream]->pause();
   }
   record[card][stream]->disconnect();
+  *len=record[card][stream]->samplesRecorded();
   record[card][stream]->closeWave();
   delete record[card][stream];
   record[card][stream]=NULL;
@@ -477,7 +496,8 @@ void MainObject::hpiGetOutputPosition(int card,unsigned *pos)
       pos[i]=0;
     }
     else {
-      pos[i]=((unsigned long long)play[card][i]->currentPosition());
+      pos[i]=1000*(unsigned long long)play[card][i]->currentPosition()/
+	play[card][i]->getSamplesPerSec();
     }
   }
 #endif  // HPI
