@@ -356,6 +356,14 @@ Color</source>
         <source>ALL</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show Only First</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDCutDialog</name>
@@ -428,6 +436,14 @@ Cart</source>
         <source>ALL</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show Only First</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -668,6 +684,38 @@ Marker</source>
         <source>R</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rivendell Web Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to download peak data, error was:
+&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDEditPanelName</name>
+    <message>
+        <source>Edit Panel Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Panel &amp;Name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDExceptionDialog</name>
@@ -1006,32 +1054,6 @@ figure for the report period.
         <source>File does not exist!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cannot open file!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unsupported file type!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Audio Exists</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This will overwrite the existing recording.
-Do you want to proceed?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Empty Clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Importing this cut will also empty the clipboard.
-Do you still want to proceed?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import Complete</source>
         <translation type="unfinished"></translation>
@@ -1040,23 +1062,6 @@ Do you still want to proceed?</source>
         <source>Import complete!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Import Aborted</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>The import has been aborted.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Import Failed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>The importer encountered an error.
-Please check your importer configuration and try again.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>File Exists</source>
         <translation type="unfinished"></translation>
@@ -1066,30 +1071,6 @@ Please check your importer configuration and try again.</source>
 Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>File Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Cannot open file in archive!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unsupported file type in archive!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>No Access</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to open the file for writing!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>OK</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Export Complete</source>
         <translation type="unfinished"></translation>
@@ -1099,20 +1080,15 @@ Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Export Aborted</source>
+        <source>Export Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>The export has been aborted.</source>
+        <source>Import Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Export Failed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>The Exporter encountered an error.
-Please check your configuration and try again.</source>
+        <source>Abort</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1157,6 +1133,60 @@ Please check your configuration and try again.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDListGroups</name>
+    <message>
+        <source>Select Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NAME</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DESCRIPTION</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDListLogs</name>
+    <message>
+        <source>Select Log - User: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NAME</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DESCRIPTION</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SERVICE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDListSelector</name>
     <message>
@@ -1329,6 +1359,62 @@ please try again!</source>
         <source>Upload</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Short Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Low Level</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>High Level</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Downloading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Internal Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Interrupted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Playing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Waiting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Device Busy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No Such Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown Audio Format</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDReport</name>
@@ -1380,6 +1466,22 @@ please try again!</source>
         <source>Unable to open report file!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RadioTraffic.com Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>VisualTraffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CounterPoint Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music1 Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDSoundPanel</name>
