@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcae.cpp,v 1.47.2.3 2009/06/05 16:57:32 cvs Exp $
+//      $Id: rdcae.cpp,v 1.58 2010/10/04 13:22:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,8 +23,6 @@
 #include <unistd.h>
 #include <errno.h>
 #include <sys/types.h>
-#include <sys/ipc.h>
-#include <sys/shm.h>
 #include <syslog.h>
 
 #include <qobject.h>
@@ -32,14 +30,19 @@
 
 #include <qsocketdevice.h>
 #include <qtimer.h>
+#include <qstringlist.h>
 
+#include <rddb.h>
 #include <rdcae.h>
 #include <rddebug.h>
+#include <rdescape_string.h>
 
-
-RDCae::RDCae(QObject *parent,const char *name)
+RDCae::RDCae(RDStation *station,RDConfig *config,
+	     QObject *parent,const char *name)
   : QObject(parent,name)
 {
+  cae_station=station;
+  cae_config=config;
   cae_connected=false;
   argnum=0;
   argptr=0;
@@ -50,33 +53,34 @@ RDCae::RDCae(QObject *parent,const char *name)
   cae_socket=new QSocketDevice(QSocketDevice::Stream);
   cae_socket->setBlocking(false);
 
+  //
+  // Meter Connection
+  //
+  cae_meter_socket=new QSocketDevice(QSocketDevice::Datagram);
+  cae_meter_socket->setBlocking(false);
+  for(Q_INT16 i=30000;i<30100;i++) {
+    if(cae_meter_socket->bind(QHostAddress(),i)) {
+      i=31000;
+    }
+  }
+
   //
   // Initialize Data Structures
   //
   for(int i=0;i<RD_MAX_CARDS;i++) {
     for(int j=0;j<RD_MAX_PORTS;j++) {
       input_status[i][j]=false;
+      for(unsigned k=0;k<2;k++) {
+	cae_input_levels[i][j][k]=-10000;
+	cae_output_levels[i][j][k]=-10000;
+      }
     }
     for(int j=0;j<RD_MAX_STREAMS;j++) {
       cae_handle[i][j]=-1;
+      cae_output_positions[i][j]=0;
     }
   }
 
-  //
-  // Attach Meter Block Segment
-  //
-  if((meter_block_id=shmget(RD_METER_SHM_KEY,0,0))<0) {
-    fprintf(stderr," SHM error, failed to get meter block id : %s\n",
-			       strerror(errno));
-    meter_block=NULL;
-    return;
-  }
-  meter_block=(RDMeterBlock *)shmat(meter_block_id,NULL,0);
-  if (meter_block == ((void*) -1)){
-    meter_block = NULL;
-    fprintf(stderr," SHM error, failed to allocate meter block : %s\n",
-	    strerror(errno));
-  }
   //
   // The Clock Timer
   //
@@ -87,37 +91,45 @@ RDCae::RDCae(QObject *parent,const char *name)
 
 
 RDCae::~RDCae() {
-  if(meter_block!=NULL) {
-    shmdt(meter_block);
-  }
   delete cae_socket;
 }
 
 
-void RDCae::connectHost(QString hostname,Q_UINT16 hostport,QString password)
+void RDCae::connectHost()
 {
+  QString sql;
+  RDSqlQuery *q;
   int count=10;
   QHostAddress addr;
   QTimer *timer=new QTimer(this,"read_timer");
   connect(timer,SIGNAL(timeout()),this,SLOT(readyData()));
   timer->start(CAE_POLL_INTERVAL);
 
-  if(hostname.lower()==QString("localhost")) {
-    hostname=QString("127.0.0.1");
+  addr.setAddress("127.0.0.1");
+  if(cae_station->caeStation()!="localhost") {
+    sql=QString().sprintf("select IPV4_ADDRESS from STATIONS where NAME=\"%s\"",
+			  (const char *)RDEscapeString(cae_station->
+						       caeStation()));
+    q=new RDSqlQuery(sql);
+    if(q->first()) {
+      addr.setAddress(q->value(0).toString());
+    }
+    delete q;
   }
-  addr.setAddress(hostname);
-  cae_password=password;
-  while((!cae_socket->connect(addr,hostport))&&(--count>0)) {
+  while((!cae_socket->connect(addr,CAED_TCP_PORT))&&(--count>0)) {
     usleep(100000);
   } 
+  usleep(100000);
   if(count>0) {
-    SendCommand(QString().sprintf("PW %s!",(const char *)cae_password));
+    SendCommand(QString().sprintf("PW %s!",
+				  (const char *)cae_config->password()));
     for(int i=0;i<RD_MAX_CARDS;i++) {
       SendCommand(QString().sprintf("TS %d!",i));
       for(int j=0;j<RD_MAX_PORTS;j++) {
 	SendCommand(QString().sprintf("IS %d %d!",i,j));
       }
     }
+    SendCommand(QString().sprintf("ME %u!",cae_meter_socket->port()));
   }
 }
 
@@ -281,25 +293,19 @@ bool RDCae::inputStatus(int card,int port) const
 }
 
 
-void RDCae::inputMeterUpdate(int card,int port,short levels[2]) const
+void RDCae::inputMeterUpdate(int card,int port,short levels[2])
 {
-  if (meter_block){
-    levels[0]=meter_block->input_meter[card][port][0];
-    levels[1]=meter_block->input_meter[card][port][1];
-  }else {
-    levels[0] = levels[1] = -10000;
-  }
+  UpdateMeters();
+  levels[0]=cae_input_levels[card][port][0];
+  levels[1]=cae_input_levels[card][port][1];
 }
 
 
-void RDCae::outputMeterUpdate(int card,int port,short levels[2]) const
+void RDCae::outputMeterUpdate(int card,int port,short levels[2])
 {
-  if (meter_block){
-    levels[0]=meter_block->output_meter[card][port][0];
-    levels[1]=meter_block->output_meter[card][port][1];
-  } else {
-    levels[0] = levels[1] = -10000;
-  }
+  UpdateMeters();
+  levels[0]=cae_output_levels[card][port][0];
+  levels[1]=cae_output_levels[card][port][1];
 }
 
 
@@ -325,7 +331,7 @@ void RDCae::requestTimescale(int card)
 bool RDCae::playPortActive(int card,int port,int except_stream)
 {
   for(int i=0;i<RD_MAX_STREAMS;i++) {
-    if(meter_block && meter_block->output_state[card][port][i]&&(i!=except_stream)) {
+    if(cae_output_status_flags[card][port][i]&&(i!=except_stream)) {
       return true;
     }
   }
@@ -335,11 +341,16 @@ bool RDCae::playPortActive(int card,int port,int except_stream)
 
 void RDCae::setPlayPortActive(int card,int port,int stream)
 {
-  if (meter_block){
-    meter_block->output_state[card][port][stream]=true;
-  }
+  cae_output_status_flags[card][port][stream]=true;
 }
 
+
+void RDCae::readyData()
+{
+  readyData(0,0,"");
+}
+
+
 void RDCae::readyData(int *stream,int *handle,QString name)
 {
   char buf[256];
@@ -372,7 +383,7 @@ void RDCae::readyData(int *stream,int *handle,QString name)
 	args[argnum++][argptr]=0;
 	if(stream==NULL) {
 	  cmd.load(args,argnum,argptr);
-          /*
+	  /*
 	  // ************************************
 	  printf("DISPATCHING: ");
 	  for(int z=0;z<cmd.argNum();z++) {
@@ -380,7 +391,7 @@ void RDCae::readyData(int *stream,int *handle,QString name)
 	  }
 	  printf("\n");
 	  // ************************************
-          */
+	  */
 	  DispatchCommand(&cmd);
 	}
 	else {
@@ -422,10 +433,10 @@ void RDCae::clockData()
   for(int i=0;i<RD_MAX_CARDS;i++) {
     for(int j=0;j<RD_MAX_STREAMS;j++) {
       if(cae_handle[i][j]>=0) {
-	if(meter_block && (meter_block->output_position[i][j]!=cae_pos[i][j])) {
+	if(cae_output_positions[i][j]!=cae_pos[i][j]) {
 	  emit playPositionChanged(cae_handle[i][j],
-				   meter_block->output_position[i][j]);
-	  cae_pos[i][j]=meter_block->output_position[i][j];
+				   cae_output_positions[i][j]);
+	  cae_pos[i][j]=cae_output_positions[i][j];
 	}
       }
     }
@@ -472,9 +483,7 @@ void RDCae::DispatchCommand(RDCmdCache *cmd)
 	  if(cae_handle[i][j]==handle) {
 	    cae_handle[i][j]=-1;
 	    for(unsigned k=0;k<RD_MAX_PORTS;k++) {
-	      if (meter_block){
-	    	meter_block->output_state[i][k][j]=false;
-	      }
+	      cae_output_status_flags[i][k][j]=false;
 	    }
 	  }
 	}
@@ -489,9 +498,9 @@ void RDCae::DispatchCommand(RDCmdCache *cmd)
       sscanf(cmd->arg(2),"%u",&pos);
       for(int i=0;i<RD_MAX_CARDS;i++) {
 	for(int j=0;j<RD_MAX_STREAMS;j++) {
-	  if(meter_block && (cae_handle[i][j]==handle)) {
-	    emit playPositionChanged(handle,
-				     meter_block->output_position[i][j]);
+	  if(cae_handle[i][j]==handle) {
+	    //emit playPositionChanged(handle,cae_output_positions[i][j]);
+	    emit playPositionChanged(handle,pos);
 	  }
 	}
       }
@@ -529,8 +538,9 @@ void RDCae::DispatchCommand(RDCmdCache *cmd)
   }
 
   if(!strcmp(cmd->arg(0),"UR")) {   // Unload Record
-    if(cmd->arg(3)[0]=='+') {
-      emit recordUnloaded(CardNumber(cmd->arg(1)),StreamNumber(cmd->arg(2)));
+    if(cmd->arg(4)[0]=='+') {
+      emit recordUnloaded(CardNumber(cmd->arg(1)),StreamNumber(cmd->arg(2)),
+			  QString(cmd->arg(3)).toUInt());
     }
   }
 
@@ -594,3 +604,36 @@ int RDCae::GetHandle(const char *arg)
   sscanf(arg,"%d",&n);
   return n;
 }
+
+
+void RDCae::UpdateMeters()
+{
+  char msg[1501];
+  int n;
+  QStringList args;
+
+  while((n=cae_meter_socket->readBlock(msg,1500))>0) {
+    msg[n]=0;
+    args=args.split(" ",msg);
+    if(args[0]=="ML") {
+      if(args.size()==6) {
+	if(args[1]=="I") {
+	  cae_input_levels[args[2].toInt()][args[3].toInt()][0]=args[4].toInt();
+	  cae_input_levels[args[2].toInt()][args[3].toInt()][1]=args[5].toInt();
+	}
+	if(args[1]=="O") {
+	  cae_output_levels[args[2].toInt()][args[3].toInt()][0]=
+	    args[4].toInt();
+	  cae_output_levels[args[2].toInt()][args[3].toInt()][1]=
+	    args[5].toInt();
+	}
+      }
+    }
+
+    if(args[0]=="MP") {
+      if(args.size()==4) {
+	cae_output_positions[args[1].toInt()][args[2].toInt()]=args[3].toUInt();
+      }
+    }
+  }
+}
