@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcut.h,v 1.37 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdcut.h,v 1.44 2011/01/25 19:28:48 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,6 +25,9 @@
 #include <qobject.h>
 
 #include <rdwavedata.h>
+#include <rdsettings.h>
+#include <rdstation.h>
+#include <rduser.h>
 
 #ifndef RDCUT_H
 #define RDCUT_H
@@ -55,6 +58,8 @@ class RDCut
   void setOutcue(const QString &string) const;
   QString isrc(IsrcFormat fmt=RawIsrc) const;
   void setIsrc(const QString &isrc) const;
+  QString isci() const;
+  void setIsci(const QString &isci) const;
   unsigned length() const;
   void setLength(int length) const;
   QDateTime originDatetime(bool *valid) const;
@@ -75,6 +80,8 @@ class RDCut
   void setWeight(int value) const;
   QDateTime lastPlayDatetime(bool *valid) const;
   void setLastPlayDatetime(const QDateTime &datetime,bool valid) const;
+  QDateTime uploadDatetime(bool *valid) const;
+  void setUploadDatetime(const QDateTime &datetime,bool valid) const;
   unsigned playCounter() const;
   void setPlayCounter(unsigned count) const;
   RDCut::Validity validity() const;
@@ -103,6 +110,8 @@ class RDCut
   void setSegueStartPoint(int point) const;
   int segueEndPoint(bool calc=false) const;
   void setSegueEndPoint(int point) const;
+  int segueGain() const;
+  void setSegueGain(int gain) const;
   int hookStartPoint(bool calc=false) const;
   void setHookStartPoint(int point) const;
   int hookEndPoint(bool calc=false) const;
@@ -114,16 +123,23 @@ class RDCut
   int effectiveStart() const;
   int effectiveEnd() const;
   void logPlayout() const;
-  bool copyTo(const QString &cutname) const;
-  void getMetadata(RDWaveData *data);
-  void setMetadata(RDWaveData *data);
-  bool checkInRecording(const QString &stationname) const;
+  bool copyTo(RDStation *station,RDUser *user,const QString &cutname) const;
+  void getMetadata(RDWaveData *data) const;
+  void setMetadata(RDWaveData *data) const;
+  QString xml() const;
+  bool checkInRecording(const QString &stationname,RDSettings *settings,
+			unsigned msecs) const;
   void autoTrim(RDCut::AudioEnd end,int level);
   void autoSegue(int level,int length);
   void reset() const;
   void connect(QObject *receiver,const char *member) const;
   void disconnect(QObject *receiver,const char *member) const;
+  static QString cutName(unsigned cartnum,unsigned cutnum);
+  static unsigned cartNumber(const QString &cutname);
+  static unsigned cutNumber(const QString &cutname);
+  static bool exists(unsigned cartnum,unsigned cutnum);
   static bool exists(const QString &cutname);
+  static QString pathName(unsigned cartnum,unsigned cutnum);
   static QString pathName(const QString &cutname);
 
  private:
@@ -138,6 +154,7 @@ class RDCut
   QSignal *cut_signal;
   QSqlDatabase *cut_db;
   QString cut_name;
+  unsigned cart_number;
   unsigned cut_number;
 };
 
