@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddropbox.cpp,v 1.5.2.1 2008/11/29 15:48:09 fredg Exp $
+//      $Id: rddropbox.cpp,v 1.9 2010/07/29 19:32:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -253,6 +253,43 @@ void RDDropbox::setLogPath(const QString &path) const
 }
 
 
+bool RDDropbox::createDates() const
+{
+  return RDBool(RDGetSqlValue("DROPBOXES","ID",box_id,"IMPORT_CREATE_DATES").
+	       toString());
+}
+
+
+void RDDropbox::setCreateDates(bool state) const
+{
+  SetRow("IMPORT_CREATE_DATES",state);
+}
+
+
+int RDDropbox::createStartdateOffset() const
+{
+  return RDGetSqlValue("DROPBOXES","ID",box_id,"CREATE_STARTDATE_OFFSET").toInt();
+}
+
+
+void RDDropbox::setCreateStartdateOffset(int offset) const
+{
+  SetRow("CREATE_STARTDATE_OFFSET",offset);
+}
+
+
+int RDDropbox::createEnddateOffset() const
+{
+  return RDGetSqlValue("DROPBOXES","ID",box_id,"CREATE_ENDDATE_OFFSET").toInt();
+}
+
+
+void RDDropbox::setCreateEnddateOffset(int offset) const
+{
+  SetRow("CREATE_ENDDATE_OFFSET",offset);
+}
+
+
 void RDDropbox::SetRow(const QString &param,int value) const
 {
   RDSqlQuery *q;
