@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdedit_audio.cpp,v 1.9 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdedit_audio.cpp,v 1.26 2011/05/02 21:18:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,19 +24,24 @@
 #include <math.h>
 #include <qpainter.h>
 #include <qsignalmapper.h>
+#include <qmessagebox.h>
 
 #include <rdconf.h>
 #include <rd.h>
 #include <rdmixer.h>
+#include <rdcut.h>
 #include <rdedit_audio.h>
-
+#include <rdaudioinfo.h>
+#include <rdtrimaudio.h>
 
 RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
-			 int card,int port,int preroll,int trim_level,
-			 QWidget *parent,const char *name)
+			 RDStation *station,int card,int port,int preroll,
+			 int trim_level,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   edit_cae=cae;
+  edit_station=station;
+  edit_user=user;
   edit_card=card;
   edit_port=port;
   edit_stream=-1;
@@ -100,22 +105,35 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   //
   // The Audio
   //
-  edit_wave=new RDWaveFile(QString(RD_AUDIO_ROOT)+QString("/")+
-			  edit_cut->cutName()+QString(".")+
-			  QString(RD_AUDIO_EXTENSION));
-  edit_wave->openWave();
   connect(edit_cae,SIGNAL(playing(int)),this,SLOT(playedData(int)));
   connect(edit_cae,SIGNAL(playStopped(int)),this,SLOT(pausedData(int)));
   connect(edit_cae,SIGNAL(playPositionChanged(int,unsigned)),
 	  this,SLOT(positionData(int,unsigned)));
   edit_cae->loadPlay(edit_card,edit_cut->cutName(),&edit_stream,&edit_handle);
   RDSetMixerOutputPort(edit_cae,edit_card,edit_stream,edit_port);
+  RDAudioInfo *info=new RDAudioInfo(station,this);
+  RDAudioInfo::ErrorCode audio_err;
+  info->setCartNumber(RDCut::cartNumber(cut_name));
+  info->setCutNumber(RDCut::cutNumber(cut_name));
 
+  if((audio_err=info->runInfo(user->name(),user->password()))==
+     RDAudioInfo::ErrorOk) {
+    edit_sample_rate=info->sampleRate();
+    edit_sample_length=info->frames();
+    edit_channels=info->channels();
+  }
+  else {
+    fprintf(stderr,"unable to download cut data, error was: \"%s\".\n",
+	    (const char *)RDAudioInfo::errorText(audio_err));
+    edit_sample_rate=RD_DEFAULT_SAMPLE_RATE;
+    edit_sample_length=info->frames();
+    edit_channels=2;
+  }
+  delete info;
   edit_gain=EDITAUDIO_DEFAULT_GAIN;
-  edit_preroll=edit_wave->getSamplesPerSec()*preroll/1000;
-
+  edit_preroll=edit_sample_rate*preroll/1000;
   for(unsigned i=0;i<(8*sizeof(unsigned));i++) {
-    if((edit_wave->getSampleLength()/(1<<i))<896256) {
+    if((edit_sample_length/(1<<i))<896256) {
       edit_max_factor_x=1<<i;
       i=8*sizeof(unsigned);
     }
@@ -152,6 +170,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_play_cursor_button->setGeometry(20,425,65,45);
   edit_play_cursor_button->
     setPalette(QPalette(backgroundColor(),QColor(EDITAUDIO_HIGHLIGHT_COLOR)));
+  edit_play_cursor_button->setEnabled((edit_card>=0)&&(edit_port>=0));
   connect(edit_play_cursor_button,SIGNAL(clicked()),
 	  this,SLOT(playCursorData()));
 
@@ -160,6 +179,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_play_start_button->setGeometry(90,425,65,45);
   edit_play_start_button->
     setPalette(QPalette(backgroundColor(),QColor(EDITAUDIO_HIGHLIGHT_COLOR)));
+  edit_play_start_button->setEnabled((edit_card>=0)&&(edit_port>=0));
   connect(edit_play_start_button,SIGNAL(clicked()),
 	  this,SLOT(playStartData()));
 
@@ -169,6 +189,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_pause_button->setOnColor(QColor(red));
   edit_pause_button->
     setPalette(QPalette(backgroundColor(),QColor(EDITAUDIO_HIGHLIGHT_COLOR)));
+  edit_pause_button->setEnabled((edit_card>=0)&&(edit_port>=0));
   connect(edit_pause_button,SIGNAL(clicked()),this,SLOT(pauseData()));
 
   edit_stop_button=new RDTransportButton(RDTransportButton::Stop,
@@ -178,6 +199,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_stop_button->setOnColor(QColor(red));
   edit_stop_button->
     setPalette(QPalette(backgroundColor(),QColor(EDITAUDIO_HIGHLIGHT_COLOR)));
+  edit_stop_button->setEnabled((edit_card>=0)&&(edit_port>=0));
   connect(edit_stop_button,SIGNAL(clicked()),this,SLOT(stopData()));
 
   edit_loop_button=new RDTransportButton(RDTransportButton::Loop,
@@ -186,6 +208,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_loop_button->off();
   edit_loop_button->
     setPalette(QPalette(backgroundColor(),QColor(EDITAUDIO_HIGHLIGHT_COLOR)));
+  edit_loop_button->setEnabled((edit_card>=0)&&(edit_port>=0));
   connect(edit_loop_button,SIGNAL(clicked()),this,SLOT(loopData()));
 
   //
@@ -580,9 +603,6 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
 	       (int)RDEditAudio::HookStart);
   connect(edit_cue_button[RDEditAudio::HookStart],SIGNAL(clicked()),
 	  button_mapper,SLOT(map()));
- // edit_cursor_edit[RDEditAudio::HookStart]->hide();
- // edit_cue_button[RDEditAudio::HookStart]->hide();
-
 
   edit_cursor_edit[RDEditAudio::HookEnd]=
     new RDMarkerEdit(this,"edit_hook_end_edit");
@@ -615,8 +635,6 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
     setMapping(edit_cue_button[RDEditAudio::HookEnd],(int)RDEditAudio::HookEnd);
   connect(edit_cue_button[RDEditAudio::HookEnd],SIGNAL(clicked()),
 	  button_mapper,SLOT(map()));
-  // edit_cursor_edit[RDEditAudio::HookEnd]->hide();
-  // edit_cue_button[RDEditAudio::HookEnd]->hide();
 
   //
   // AutoTrim Buttons
@@ -691,6 +709,17 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_remove_button->setFlashColor(QColor(EDITAUDIO_REMOVE_FLASH_COLOR));
   connect(edit_remove_button,SIGNAL(clicked()),this,SLOT(removeButtonData()));
 
+  //
+  // Segue Fade Box
+  //
+  edit_overlap_box=new QCheckBox(this,"edit_overlap_box");
+  edit_overlap_box->setGeometry(570,510,15,15);
+  label=new QLabel(edit_overlap_box,tr("No Fade on Segue Out"),
+		   this,"label");
+  label->setGeometry(590,508,130,20);
+  label->setFont(button_font);
+  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  
   //
   // Time Counters
   //
@@ -744,6 +773,16 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   //
   // The Wave Forms
   //
+  edit_peaks=new RDPeaksExport(station,this);
+  RDPeaksExport::ErrorCode conv_err;
+  edit_peaks->setCartNumber(RDCut::cartNumber(cut_name));
+  edit_peaks->setCutNumber(RDCut::cutNumber(cut_name));
+  if((conv_err=edit_peaks->runExport(user->name(),user->password()))!=
+     RDPeaksExport::ErrorOk) {
+    QMessageBox::warning(this,tr("Rivendell Web Service"),
+			 tr("Unable to download peak data, error was:\n\"")+
+			 RDPeaksExport::errorText(conv_err)+"\".");
+  }
   edit_wave_array=new QPointArray(EDITAUDIO_WAVEFORM_WIDTH-2);
   DrawMaps();
 
@@ -769,21 +808,21 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_cursor_edit[RDEditAudio::Start]->
 	  setText(RDGetTimeLength(edit_cut->startPoint(true),true));
   edit_cursors[RDEditAudio::Start]=(int)(((double)edit_cut->startPoint(true)*
-					(double)edit_wave->getSamplesPerSec())
+					(double)edit_sample_rate)
 				       /1152000.0);
   edit_cursors[RDEditAudio::Play]=edit_cursors[RDEditAudio::Start];
   baseline=edit_cursors[RDEditAudio::Start];
   edit_cursor_edit[RDEditAudio::End]->
 	  setText(RDGetTimeLength(edit_cut->endPoint(true),true));
   edit_cursors[RDEditAudio::End]=(int)(((double)edit_cut->endPoint(true)*
-				      (double)edit_wave->getSamplesPerSec())
+				      (double)edit_sample_rate)
 				     /1152000.0);
   if(edit_cut->talkStartPoint()!=-1) {
     edit_cursor_edit[RDEditAudio::TalkStart]->
       setText(RDGetTimeLength(edit_cut->talkStartPoint(),true));
     edit_cursors[RDEditAudio::TalkStart]=
       (int)(((double)edit_cut->talkStartPoint()*
-	     (double)edit_wave->getSamplesPerSec())/1152000.0);
+	     (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::TalkStart]=-1;
@@ -792,7 +831,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
     edit_cursor_edit[RDEditAudio::TalkEnd]->
       setText(RDGetTimeLength(edit_cut->talkEndPoint(),true));
     edit_cursors[RDEditAudio::TalkEnd]=(int)(((double)edit_cut->talkEndPoint()*
-			   (double)edit_wave->getSamplesPerSec())/1152000.0);
+			   (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::TalkEnd]=-1;
@@ -802,7 +841,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
       setText(RDGetTimeLength(edit_cut->segueStartPoint(),true));
     edit_cursors[RDEditAudio::SegueStart]=
       (int)(((double)edit_cut->segueStartPoint()*
-	     (double)edit_wave->getSamplesPerSec())/1152000.0);
+	     (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::SegueStart]=-1;
@@ -811,7 +850,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
     edit_cursor_edit[RDEditAudio::SegueEnd]->
       setText(RDGetTimeLength(edit_cut->segueEndPoint(),true));
     edit_cursors[RDEditAudio::SegueEnd]=(int)(((double)edit_cut->segueEndPoint()*
-			     (double)edit_wave->getSamplesPerSec())/1152000.0);
+			     (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::SegueEnd]=-1;
@@ -819,7 +858,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   if(edit_cut->fadeupPoint()!=-1) {
     edit_cursor_edit[RDEditAudio::FadeUp]->setText(RDGetTimeLength(edit_cut->fadeupPoint(),true));
     edit_cursors[RDEditAudio::FadeUp]=(int)(((double)edit_cut->fadeupPoint()*
-			 (double)edit_wave->getSamplesPerSec())/1152000.0);
+			 (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::FadeUp]=-1;
@@ -828,7 +867,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
     edit_cursor_edit[RDEditAudio::FadeDown]->
       setText(RDGetTimeLength(edit_cut->fadedownPoint(),true));
     edit_cursors[RDEditAudio::FadeDown]=(int)(((double)edit_cut->fadedownPoint()*
-			   (double)edit_wave->getSamplesPerSec())/1152000.0);
+			   (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::FadeDown]=-1;
@@ -837,7 +876,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
     edit_cursor_edit[RDEditAudio::HookStart]->
       setText(RDGetTimeLength(edit_cut->hookStartPoint(),true));
     edit_cursors[RDEditAudio::HookStart]=(int)(((double)edit_cut->hookStartPoint()*
-			     (double)edit_wave->getSamplesPerSec())/1152000.0);
+			     (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::HookStart]=-1;
@@ -846,7 +885,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
     edit_cursor_edit[RDEditAudio::HookEnd]->
       setText(RDGetTimeLength(edit_cut->hookEndPoint(),true));
     edit_cursors[RDEditAudio::HookEnd]=(int)(((double)edit_cut->hookEndPoint()*
-			   (double)edit_wave->getSamplesPerSec())/1152000.0);
+			   (double)edit_sample_rate)/1152000.0);
   }
   else {
     edit_cursors[RDEditAudio::HookEnd]=-1;
@@ -855,7 +894,13 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_gain_edit->setText(QString().sprintf("%4.1f dB",
 			     (double)edit_gain_control->value()/100.0));
   edit_trim_box->setValue(trim_level/100);
-
+  if(edit_cut->segueGain()==0) {
+    edit_overlap_box->setChecked(true);
+  }
+  else {
+    edit_overlap_box->setChecked(false);
+  }
+    
   //
   // The Mouse Pointers
   //
@@ -880,11 +925,13 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   edit_gain_edit->setReadOnly(!editing_allowed);
   trim_start_button->setEnabled(editing_allowed);
   trim_end_button->setEnabled(editing_allowed);
+  edit_overlap_box->setEnabled(editing_allowed);
 }
 
 
 RDEditAudio::~RDEditAudio()
 {
+  delete edit_peaks;
 }
 
 
@@ -905,7 +952,6 @@ void RDEditAudio::saveData()
   edit_cae->stopPlay(edit_handle);
   edit_cae->unloadPlay(edit_handle);
   SaveMarkers();
-  edit_wave->closeWave();
   done(0);
 }
 
@@ -922,8 +968,8 @@ void RDEditAudio::xFullIn()
 {
   if(edit_factor_x!=0.125) {
     edit_factor_x=0.125;
-    edit_hscroll->setRange(0,(int)((double)edit_wave->energySize()/
-				   (double)edit_wave->getChannels()*
+    edit_hscroll->setRange(0,(int)((double)edit_peaks->energySize()/
+				   (double)edit_channels*
 				   (1.0-edit_factor_x/edit_max_factor_x)));
     CenterDisplay();
     DrawMaps();
@@ -940,8 +986,8 @@ void RDEditAudio::xUp()
       edit_hscroll->setRange(0,0);
     }
     else {
-      edit_hscroll->setRange(0,(int)((double)edit_wave->energySize()/
-				     (double)edit_wave->getChannels()*
+      edit_hscroll->setRange(0,(int)((double)edit_peaks->energySize()/
+				     (double)edit_channels*
 				     (1.0-edit_factor_x/edit_max_factor_x)));
     }
     CenterDisplay();
@@ -959,8 +1005,8 @@ void RDEditAudio::xDown()
       edit_hscroll->setRange(0,0);
     }
     else {
-      edit_hscroll->setRange(0,(int)((double)edit_wave->energySize()/
-				     (double)edit_wave->getChannels()*
+      edit_hscroll->setRange(0,(int)((double)edit_peaks->energySize()/
+				     (double)edit_channels*
 				     (1.0-edit_factor_x/edit_max_factor_x)));
     }
     CenterDisplay();
@@ -1053,9 +1099,10 @@ void RDEditAudio::playStartData()
     edit_cae->
       setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
     edit_cae->play(edit_handle,(int)(1000.0*(double)
-			  ((edit_cursors[RDEditAudio::End]-
+				     ((edit_cursors[RDEditAudio::End]-
 			    edit_cursors[RDEditAudio::Start])*1152)/
-			  (double)edit_wave->getSamplesPerSec()),1000,0);
+				     (double)edit_sample_rate),
+		   RD_TIMESCALE_DIVISOR,0);
   }
   if(use_looping) {
     is_looping=true;
@@ -1081,46 +1128,47 @@ void RDEditAudio::playCursorData()
       case RDEditAudio::FadeDown:
 	length=(int)(1000.0*(double)((edit_cursors[RDEditAudio::End]-
 			   edit_cursors[RDEditAudio::Play])*1152)/
-			   (double)edit_wave->getSamplesPerSec());
+			   (double)edit_sample_rate);
 	break;
 
       case RDEditAudio::SegueStart:
       case RDEditAudio::SegueEnd:
 	length=(int)(1000.0*(double)((edit_cursors[RDEditAudio::SegueEnd]-
 		     edit_cursors[RDEditAudio::Play])*1152)/
-		     (double)edit_wave->getSamplesPerSec());
+		     (double)edit_sample_rate);
 	break;
 
       case RDEditAudio::TalkStart:
       case RDEditAudio::TalkEnd:
 	length=(int)(1000.0*(double)((edit_cursors[RDEditAudio::TalkEnd]-
 		     edit_cursors[RDEditAudio::Play])*1152)/
-		     (double)edit_wave->getSamplesPerSec());
+		     (double)edit_sample_rate);
 	break;
 
       case RDEditAudio::HookStart:
       case RDEditAudio::HookEnd:
 	length=(int)(1000.0*(double)((edit_cursors[RDEditAudio::HookEnd]-
 		     edit_cursors[RDEditAudio::Play])*1152)/
-		     (double)edit_wave->getSamplesPerSec());
+		     (double)edit_sample_rate);
 	break;
 
       case RDEditAudio::FadeUp:
 	length=(int)(1000.0*(double)((edit_cursors[RDEditAudio::FadeUp]-
 		     edit_cursors[RDEditAudio::Play])*1152)/
-		     (double)edit_wave->getSamplesPerSec());
+		     (double)edit_sample_rate);
 	break;
 
       default:
 	break;
   }
   played_cursor=edit_cursors[RDEditAudio::Play];
+
   pause_mode=false;
   if(!is_playing) {
     edit_cae->setPlayPortActive(edit_card,edit_port,edit_stream);
     edit_cae->
       setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
-    edit_cae->play(edit_handle,length,1000,0);
+    edit_cae->play(edit_handle,length,RD_TIMESCALE_DIVISOR,0);
   }
   if(use_looping) {
     is_looping=true;
@@ -1261,7 +1309,10 @@ void RDEditAudio::pausedData(int handle)
 void RDEditAudio::positionData(int handle,unsigned int pos)
 { //pos is in miliseconds
   edit_cursors[RDEditAudio::Play]=
-    (unsigned int)(((double)((pos/1000.0)*edit_wave->getSamplesPerSec())+0.5)/1152.0);
+    (unsigned int)((double)pos*edit_sample_rate/1152000.0);
+  if((edit_sample_rate%8000)!=0) { //Account for the MPEG padding!
+    edit_cursors[RDEditAudio::Play]++;
+  }
   UpdateCursors();
   UpdateCounters();
 }
@@ -1352,7 +1403,7 @@ void RDEditAudio::cueEditData(int id)
 
   old_cursor=1152*edit_cursors[id];
   if((cursor=(int)((double)(RDSetTimeLength(edit_cursor_edit[id]->text())*
-      (double)edit_wave->getSamplesPerSec()/1000.0)))<0) {
+      (double)edit_sample_rate/1000.0)))<0) {
     cursor=1152*edit_cursors[id];
     edit_cursor_edit[id]->setText(edit_cue_string);
     return;
@@ -1472,35 +1523,59 @@ void RDEditAudio::deleteHookData()
 
 void RDEditAudio::trimHeadData()
 {
-  int level;
-  int pos;
   RDEditAudio::CuePoints point;
-
-  sscanf(edit_trim_box->text(),"%d",&level);
-  if((pos=edit_wave->startTrim(-level*100+REFERENCE_LEVEL))>=0) {
+  RDTrimAudio::ErrorCode conv_err;
+  RDTrimAudio *conv=new RDTrimAudio(edit_station,this);
+  conv->setCartNumber(edit_cut->cartNumber());
+  conv->setCutNumber(edit_cut->cutNumber());
+  conv->setTrimLevel(100*edit_trim_box->value());
+  switch(conv_err=conv->runTrim(edit_user->name(),edit_user->password())) {
+  case RDTrimAudio::ErrorOk:
+    if(conv->startPoint()>=0) {
     point=edit_cue_point;
     edit_cue_point=RDEditAudio::Start;
-    PositionCursor(pos);
+    PositionCursor((double)conv->startPoint()*(double)edit_sample_rate/1000.0);
     UpdateCounters();
     edit_cue_point=point;
   }
+
+    break;
+
+  default:
+    QMessageBox::warning(this,tr("Edit Audio"),
+			 RDTrimAudio::errorText(conv_err));
+    break;
+  }
+  delete conv;
 }
 
 
 void RDEditAudio::trimTailData()
 {
-  int level;
-  int pos;
   RDEditAudio::CuePoints point;
-
-  sscanf(edit_trim_box->text(),"%d",&level);
-  if((pos=edit_wave->endTrim(-level*100+REFERENCE_LEVEL))>=0) {
+  RDTrimAudio::ErrorCode conv_err;
+  RDTrimAudio *conv=new RDTrimAudio(edit_station,this);
+  conv->setCartNumber(edit_cut->cartNumber());
+  conv->setCutNumber(edit_cut->cutNumber());
+  conv->setTrimLevel(100*edit_trim_box->value());
+  switch(conv_err=conv->runTrim(edit_user->name(),edit_user->password())) {
+  case RDTrimAudio::ErrorOk:
+    if(conv->endPoint()>=0) {
     point=edit_cue_point;
     edit_cue_point=RDEditAudio::End;
-    PositionCursor(pos);
+    PositionCursor((double)conv->endPoint()*(double)edit_sample_rate/1000.0);
     UpdateCounters();
     edit_cue_point=point;
   }
+
+    break;
+
+  default:
+    QMessageBox::warning(this,tr("Edit Audio"),
+			 RDTrimAudio::errorText(conv_err));
+    break;
+  }
+  delete conv;
 }
 
 
@@ -1619,10 +1694,10 @@ void RDEditAudio::paintEvent(QPaintEvent *e)
   // Waveforms
   //
   p->setPen(QColor(black));
-  if(edit_wave->getChannels()==1) {
+  if(edit_channels==1) {
     p->drawImage(11,11,edit_left_image);
   }
-  if(edit_wave->getChannels()==2) {
+  if(edit_channels==2) {
     p->drawImage(11,11,edit_left_image);
     p->drawImage(11,11+EDITAUDIO_WAVEFORM_HEIGHT/2,edit_right_image);
   }
@@ -1645,8 +1720,7 @@ void RDEditAudio::paintEvent(QPaintEvent *e)
   //
   // Marker Control Area
   //
-  p->drawRect(11,130+EDITAUDIO_WAVEFORM_HEIGHT,624,197);
-//  p->drawRect(11,130+EDITAUDIO_WAVEFORM_HEIGHT,551,197);
+  p->drawRect(11,130+EDITAUDIO_WAVEFORM_HEIGHT,717,197);
 
   p->end();
   delete p;
@@ -1768,12 +1842,12 @@ void RDEditAudio::keyPressEvent(QKeyEvent *e)
 	break;
 
       case Key_Left:
-	PositionCursor(-(edit_wave->getSamplesPerSec()/10),true);
+	PositionCursor(-(edit_sample_rate/10),true);
 	e->accept();
 	break;
 
       case Key_Right:
-	PositionCursor(edit_wave->getSamplesPerSec()/10,true);
+	PositionCursor(edit_sample_rate/10,true);
 	e->accept();
 	break;
 
@@ -1906,7 +1980,7 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	  edit_cursor_edit[edit_cue_point+1]->
 	    setText(RDGetTimeLength(
 		     (int)(1152000.0*(double)edit_cursors[edit_cue_point+1]/
-		 (double)edit_wave->getSamplesPerSec()),true));
+		 (double)edit_sample_rate),true));
 	}
 	if(relative) {
 	  if((edit_cursors[edit_cue_point]+cursor/1152)>
@@ -1933,7 +2007,7 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	}
 	edit_cursor_edit[edit_cue_point]->
 	  setText(RDGetTimeLength((int)(1000.0*(double)cursor/
-			       (double)edit_wave->getSamplesPerSec()),true));
+			       (double)edit_sample_rate),true));
 	edit_cae->positionPlay(edit_handle,GetTime(cursor));
 	break;
 	
@@ -1946,7 +2020,7 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	  edit_cursor_edit[edit_cue_point-1]->
 	    setText(RDGetTimeLength(
 		  (int)(1152000.0*(double)edit_cursors[edit_cue_point-1]/
-		 (double)edit_wave->getSamplesPerSec()),true));
+		 (double)edit_sample_rate),true));
 	}
 	if(relative) {
 	  if((edit_cursors[edit_cue_point]+cursor/1152)<
@@ -1960,8 +2034,8 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	  }
 	  if((edit_cue_point==RDEditAudio::End)&&
 	     ((1152*edit_cursors[edit_cue_point]+cursor)
-	      >(int)edit_wave->getSampleLength())) {
-	    cursor=edit_wave->getSampleLength()-
+	      >(int)edit_sample_length)) {
+	    cursor=edit_sample_length-
 	      1152*edit_cursors[edit_cue_point];;
 	  }
 	  edit_cursors[edit_cue_point]+=cursor/1152;
@@ -1976,8 +2050,8 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	    return false;
 	  }
 	  if((edit_cue_point==RDEditAudio::End)&&
-	     (cursor>(int)edit_wave->getSampleLength())) {
-	    cursor=edit_wave->getSampleLength();
+	     (cursor>(int)edit_sample_length)) {
+	    cursor=edit_sample_length;
 	  }
 	  edit_cursors[edit_cue_point]=cursor/1152;
 	}
@@ -1987,7 +2061,7 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	}
 	edit_cursor_edit[edit_cue_point]->
 	  setText(RDGetTimeLength((int)(1000.0*(double)cursor/
-			       (double)edit_wave->getSamplesPerSec()),true));
+			       (double)edit_sample_rate),true));
 	PreRoll(cursor,edit_cue_point);
 	break;
 	
@@ -2021,7 +2095,7 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	}
 	edit_cursor_edit[RDEditAudio::FadeUp]->
 	  setText(RDGetTimeLength((int)(1000.0*(double)cursor/
-			       (double)edit_wave->getSamplesPerSec()),true));
+			       (double)edit_sample_rate),true));
 	edit_cae->positionPlay(edit_handle,
 			    GetTime(edit_cursors[RDEditAudio::Start]*1152));
 	break;
@@ -2053,7 +2127,7 @@ bool RDEditAudio::PositionCursor(int cursor,bool relative)
 	}
 	edit_cursor_edit[RDEditAudio::FadeDown]->
 	  setText(RDGetTimeLength((int)(1000.0*(double)cursor/
-			       (double)edit_wave->getSamplesPerSec()),true));
+			       (double)edit_sample_rate),true));
 	edit_cae->positionPlay(edit_handle,GetTime(cursor));
 	break;	
 
@@ -2079,7 +2153,7 @@ void RDEditAudio::ValidateMarkers()
 	  edit_cursors[i]=edit_cursors[RDEditAudio::Start];
 	  edit_cursor_edit[i]->setText(
 	    RDGetTimeLength((int)((double)edit_cursors[i]*
-		 1152000.0/(double)edit_wave->getSamplesPerSec()),true));
+		 1152000.0/(double)edit_sample_rate),true));
 	}
 	else {
 	  edit_cursors[i]=-1;
@@ -2096,7 +2170,7 @@ void RDEditAudio::ValidateMarkers()
 	  edit_cursors[i+1]=edit_cursors[RDEditAudio::End];
 	  edit_cursor_edit[i+1]->setText(
 	    RDGetTimeLength((int)((double)edit_cursors[i+1]*
-		 1152000.0/(double)edit_wave->getSamplesPerSec()),true));
+		 1152000.0/(double)edit_sample_rate),true));
 	}
 	else {
 	  edit_cursors[i]=-1;
@@ -2127,15 +2201,15 @@ void RDEditAudio::SaveMarkers()
   edit_cut->setPlayGain(10*edit_gain_control->value());
   edit_cut->setStartPoint((int)((double)(edit_cursors[RDEditAudio::Start])*
 				1152000.0/
-				(double)edit_wave->getSamplesPerSec()));
+				(double)edit_sample_rate));
   edit_cut->setEndPoint((int)((double)(edit_cursors[RDEditAudio::End])*
 			      1152000.0/
-			      (double)edit_wave->getSamplesPerSec())+26);
+			      (double)edit_sample_rate)+26);
   if(edit_cursors[RDEditAudio::TalkStart]!=-1) {
     edit_cut->
       setTalkStartPoint((int)((double)(edit_cursors[RDEditAudio::TalkStart])*
 			      1152000.0/
-			      (double)edit_wave->getSamplesPerSec()));
+			      (double)edit_sample_rate));
   }
   else {
     edit_cut->setTalkStartPoint(-1);
@@ -2143,14 +2217,14 @@ void RDEditAudio::SaveMarkers()
   if(edit_cursors[RDEditAudio::TalkEnd]!=-1) {
     edit_cut->setTalkEndPoint((int)((double)(edit_cursors[RDEditAudio::TalkEnd])*
 				    1152000.0/
-				(double)edit_wave->getSamplesPerSec()));
+				(double)edit_sample_rate));
   }
   else {
     edit_cut->setTalkEndPoint(-1);
   }
   if(edit_cursors[RDEditAudio::SegueStart]!=-1) {
     edit_cut->setSegueStartPoint((int)((double)(edit_cursors[RDEditAudio::SegueStart])*1152000.0/
-				  (double)edit_wave->getSamplesPerSec()));
+				  (double)edit_sample_rate));
   }
   else {
     edit_cut->setSegueStartPoint(-1);
@@ -2158,14 +2232,14 @@ void RDEditAudio::SaveMarkers()
   if(edit_cursors[RDEditAudio::SegueEnd]!=-1) {
     edit_cut->
       setSegueEndPoint((int)((double)(edit_cursors[RDEditAudio::SegueEnd])*
-			     1152000.0/(double)edit_wave->getSamplesPerSec()));
+			     1152000.0/(double)edit_sample_rate));
   }
   else {
     edit_cut->setSegueEndPoint(-1);
   }
   if(edit_cursors[RDEditAudio::FadeUp]!=-1) {
     edit_cut->setFadeupPoint((int)((double)(edit_cursors[RDEditAudio::FadeUp])*1152000.0/
-				  (double)edit_wave->getSamplesPerSec()));
+				  (double)edit_sample_rate));
   }
   else {
     edit_cut->setFadeupPoint(-1);
@@ -2173,14 +2247,14 @@ void RDEditAudio::SaveMarkers()
   if(edit_cursors[RDEditAudio::FadeDown]!=-1) {
     edit_cut->
       setFadedownPoint((int)((double)(edit_cursors[RDEditAudio::FadeDown])*
-			     1152000.0/(double)edit_wave->getSamplesPerSec()));
+			     1152000.0/(double)edit_sample_rate));
   }
   else {
     edit_cut->setFadedownPoint(-1);
   }
   if(edit_cursors[RDEditAudio::HookStart]!=-1) {
     edit_cut->setHookStartPoint((int)((double)(edit_cursors[RDEditAudio::HookStart])*1152000.0/
-				  (double)edit_wave->getSamplesPerSec()));
+				  (double)edit_sample_rate));
   }
   else {
     edit_cut->setHookStartPoint(-1);
@@ -2188,13 +2262,19 @@ void RDEditAudio::SaveMarkers()
   if(edit_cursors[RDEditAudio::HookEnd]!=-1) {
     edit_cut->setHookEndPoint((int)((double)(edit_cursors[RDEditAudio::HookEnd])*
 				    1152000.0/
-				    (double)edit_wave->getSamplesPerSec()));
+				    (double)edit_sample_rate));
   }
   else {
     edit_cut->setHookEndPoint(-1);
   }
   edit_cut->setLength(edit_cut->endPoint(true)-edit_cut->startPoint(true));
   edit_cut->setPlayGain(edit_gain_control->value());
+  if(edit_overlap_box->isChecked()) {
+    edit_cut->setSegueGain(0);
+  }
+  else {
+    edit_cut->setSegueGain(RD_FADE_DEPTH);
+  }
 }
 
 
@@ -2204,19 +2284,19 @@ void RDEditAudio::LoopRegion(int cursor0,int cursor1)
 
   if(cursor1!=-1) {
     length=(int)(1000.0*(double)((cursor1-cursor0)*
-				 1152)/(double)edit_wave->getSamplesPerSec());
+				 1152)/(double)edit_sample_rate);
   }
   if(cursor0==-1) {
     edit_cae->positionPlay(edit_handle,0);
     edit_cae->
       setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
-    edit_cae->play(edit_handle,length,1000,0);
+    edit_cae->play(edit_handle,length,RD_TIMESCALE_DIVISOR,0);
   }
   else {
     edit_cae->positionPlay(edit_handle,GetTime(cursor0*1152));
     edit_cae->
       setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
-    edit_cae->play(edit_handle,length,1000,0);
+    edit_cae->play(edit_handle,length,RD_TIMESCALE_DIVISOR,0);
   }
 }
 
@@ -2230,7 +2310,7 @@ void RDEditAudio::UpdateCounters()
 
   edit_overall_edit->setText(RDGetTimeLength(
 	  (int)(1000.0*(double)((edit_cursors[RDEditAudio::Play]-baseline)*1152)/
-	  (double)edit_wave->getSamplesPerSec()),true,true));
+	  (double)edit_sample_rate),true,true));
   if(prev_cue_point!=RDEditAudio::Play) {
     edit_cursor_edit[prev_cue_point]->clearFocus();
     edit_cursor_edit[prev_cue_point]->deselect();
@@ -2356,7 +2436,7 @@ void RDEditAudio::UpdateCounters()
     null_region=true;
   }
   if(cursor1==-1) {
-    cursor1=edit_wave->getSampleLength()/1152;
+    cursor1=edit_sample_length/1152;
     null_region=true;
   }
   if(null_region||(edit_cue_point==RDEditAudio::Play)) {
@@ -2366,13 +2446,13 @@ void RDEditAudio::UpdateCounters()
   else {
     edit_region_edit->setText(RDGetTimeLength(
 			    (int)(1000.0*(double)((cursor1-cursor0)*1152)/
-			    (double)edit_wave->getSamplesPerSec()),true,true));
+			    (double)edit_sample_rate),true,true));
     edit_region_edit->setEnabled(true);
   }
   edit_size_edit->setText(RDGetTimeLength(
 			 (int)(1000.0*(double)((edit_cursors[RDEditAudio::End]-
 					edit_cursors[RDEditAudio::Start])*1152)/
-		         (double)edit_wave->getSamplesPerSec()),true,true));
+		         (double)edit_sample_rate),true,true));
   prev_cue_point=edit_cue_point;
 }
 
@@ -2381,13 +2461,13 @@ void RDEditAudio::DrawMaps()
 {
   QPixmap *pix=NULL;
 
-  if(edit_wave->getChannels()==1) {
+  if(edit_channels==1) {
     pix=new QPixmap(EDITAUDIO_WAVEFORM_WIDTH,EDITAUDIO_WAVEFORM_HEIGHT);
     DrawWave(EDITAUDIO_WAVEFORM_WIDTH,EDITAUDIO_WAVEFORM_HEIGHT,0,"",pix);
     edit_left_image=pix->convertToImage();
     delete pix;
   }
-  if(edit_wave->getChannels()==2) {
+  if(edit_channels==2) {
     pix=new QPixmap(EDITAUDIO_WAVEFORM_WIDTH,EDITAUDIO_WAVEFORM_HEIGHT/2);
     DrawWave(EDITAUDIO_WAVEFORM_WIDTH,EDITAUDIO_WAVEFORM_HEIGHT/2,0,tr("L"),
 	     pix);
@@ -2402,10 +2482,10 @@ void RDEditAudio::DrawMaps()
 
 void RDEditAudio::UpdateCursors()
 {
-  if(edit_wave->getChannels()==1) {
+  if(edit_channels==1) {
     DrawCursors(11,11,EDITAUDIO_WAVEFORM_WIDTH,EDITAUDIO_WAVEFORM_HEIGHT,0);
   }
-  if(edit_wave->getChannels()==2) {
+  if(edit_channels==2) {
     DrawCursors(11,11,EDITAUDIO_WAVEFORM_WIDTH,EDITAUDIO_WAVEFORM_HEIGHT/2,0);
     DrawCursors(11,11+EDITAUDIO_WAVEFORM_HEIGHT/2,EDITAUDIO_WAVEFORM_WIDTH,
 		EDITAUDIO_WAVEFORM_HEIGHT/2,1);
@@ -2624,6 +2704,9 @@ void RDEditAudio::EraseCursor(int xpos,int ypos,int xsize,int ysize,int chan,
 {
   int x;
 
+  if(edit_hscroll==NULL) {
+    return;
+  }
   x=(int)((double)(samp-edit_hscroll->value())/edit_factor_x);
   if(x!=prev) {
     QPainter *p=new QPainter(this);
@@ -2694,10 +2777,11 @@ void RDEditAudio::DrawWave(int xsize,int ysize,int chan,QString label,
   //
   for(int i=1;i<(xsize-3);i++) {
     offset=(unsigned)((double)i*edit_factor_x*
-		      (double)edit_wave->getChannels()+
-		      (double)edit_wave->getChannels()*
+		      (double)edit_channels+
+		      (double)edit_channels*
 		      (double)origin_x);
-    if(offset>=edit_wave->energySize()) {
+    if(offset>=edit_peaks->energySize()) {
+      //    if(offset>=edit_wave->energySize()) {
       p->fillRect(i,1,xsize-i,ysize-2,
 		  QBrush(QColor(EDITAUDIO_HIGHLIGHT_COLOR)));
       continue;
@@ -2714,14 +2798,15 @@ void RDEditAudio::DrawWave(int xsize,int ysize,int chan,QString label,
   p->lineTo(xsize,vert-ref_line);
 
   p->translate(1,ysize/2);
-  if(edit_wave->energySize()>0) {
+  if(edit_peaks->energySize()>0) {
+    //  if(edit_wave->energySize()>0) {
 
     //
     // Time Tick Marks
     //
     p->setFont(QFont("Helvetica",8,QFont::Normal));
-    for(unsigned i=0;i<2*edit_wave->energySize();
-	i+=(int)(edit_factor_x*(double)edit_wave->getSamplesPerSec()/576.0)) {
+    for(unsigned i=0;i<2*edit_peaks->energySize();
+	i+=(int)(edit_factor_x*(double)edit_sample_rate/576.0)) {
       offset=(int)((double)(i-origin_x)/edit_factor_x);
       if((offset>0)&&(offset<(EDITAUDIO_WAVEFORM_WIDTH-2))) {
 	p->setPen(QColor(green));
@@ -2730,7 +2815,7 @@ void RDEditAudio::DrawWave(int xsize,int ysize,int chan,QString label,
 	p->setPen(QColor(red));
 	p->drawText(offset+3,ysize/2-4,
 		    RDGetTimeLength((int)((1152000.0*(double)i)/
-	       		  (double)edit_wave->getSamplesPerSec()+1000.0),
+	       		  (double)edit_sample_rate+1000.0),
 				   false,edit_factor_x<0.5));
       }
     }
@@ -2745,13 +2830,13 @@ void RDEditAudio::DrawWave(int xsize,int ysize,int chan,QString label,
     edit_wave_array->setPoint(0,0,0);
     for(int i=1;i<(xsize-3);i++) {
       offset=(unsigned)((double)i*edit_factor_x*
-			(double)edit_wave->getChannels()+
-			(double)edit_wave->getChannels()*
+			(double)edit_channels+
+			(double)edit_channels*
 			(double)origin_x+(double)chan);
-      if(offset<edit_wave->energySize()) {
+      if(offset<edit_peaks->energySize()) {
 	edit_wave_array->setPoint(i,i+(int)((double)chan/(2.0*edit_factor_x)),
-			       (int)(edit_wave->energy(offset)*ysize*
-				     size_y/65534));
+				  (int)(edit_peaks->energy(offset)*ysize*
+					size_y/65534));
       }
       else {
 	edit_wave_array->setPoint(i,i,0);
@@ -2763,12 +2848,12 @@ void RDEditAudio::DrawWave(int xsize,int ysize,int chan,QString label,
     edit_wave_array->setPoint(0,0,0);
     for(int i=1;i<(xsize-3);i++) {
       offset=(unsigned)((double)i*edit_factor_x*
-			(double)edit_wave->getChannels()+
-			(double)edit_wave->getChannels()*
+			(double)edit_channels+
+			(double)edit_channels*
 			(double)origin_x+(double)chan);
-      if(offset<edit_wave->energySize()) {
+      if(offset<edit_peaks->energySize()) {
 	edit_wave_array->setPoint(i,i+(int)((double)chan/(2.0*edit_factor_x)),
-			      (int)(-edit_wave->energy(offset)*
+			      (int)(-edit_peaks->energy(offset)*
 				    ysize*size_y/65534));
       }
       else {
@@ -2812,8 +2897,8 @@ void RDEditAudio::CenterDisplay()
 
 int RDEditAudio::GetTime(int samples)
 {
-  if(samples>(int)edit_wave->getSampleLength()) {
+  if(samples>(int)edit_sample_length) {
     return -1;
   }
-  return (int)(1000.0*(double)samples/(double)edit_wave->getSamplesPerSec());
+  return (int)(1000.0f*(double)samples/(double)edit_sample_rate);
 }
