@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_event.cpp,v 1.93.2.3 2009/11/17 17:45:53 cvs Exp $
+//      $Id: rdlog_event.cpp,v 1.99 2011/01/04 17:21:12 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -43,6 +43,9 @@ RDLogEvent::RDLogEvent(QString name)
 
 RDLogEvent::~RDLogEvent()
 {
+  for(unsigned i=0;i<log_line.size();i++) {
+    delete log_line[i];
+  }
 }
 
 
@@ -74,6 +77,19 @@ bool RDLogEvent::exists(int line)
 }
 
 
+bool RDLogEvent::exists(const QTime &hard_time,int except_line)
+{
+  for(int i=0;i<size();i++) {
+    if((logLine(i)->timeType()==RDLogLine::Hard)&&
+       (logLine(i)->startTime(RDLogLine::Logged)==hard_time)&&
+       (i!=except_line)) {
+      return true;
+    }
+  }
+  return false;
+}
+
+
 QString RDLogEvent::logName() const
 {
   return log_name;
@@ -229,8 +245,10 @@ from %s left join CART on %s.CART_NUMBER=CART.NUMBER order by COUNT",
     if(q->value(0).toInt()>log_max_id) {
       log_max_id=q->value(0).toInt();
     }
-    line.setStartTime(RDLogLine::Imported,q->value(2).toTime()); // Start Time
-    line.setStartTime(RDLogLine::Logged,q->value(2).toTime());
+    line.setStartTime(RDLogLine::Imported,
+		      QTime().addMSecs(q->value(2).toInt())); // Start Time
+    line.setStartTime(RDLogLine::Logged,
+		      QTime().addMSecs(q->value(2).toInt()));
     line.
       setTimeType((RDLogLine::TimeType)q->value(3).toInt());   // Time Type
     if((line.timeType()==RDLogLine::Hard)&&
@@ -243,7 +261,7 @@ from %s left join CART on %s.CART_NUMBER=CART.NUMBER order by COUNT",
     line.setGraceTime(q->value(28).toInt());                // Grace Time
     line.setSource((RDLogLine::Source)q->value(30).toUInt());
     line.setLinkEventName(q->value(47).toString());         // Link Event Name
-    line.setLinkStartTime(q->value(48).toTime());           // Link Start Time
+    line.setLinkStartTime(QTime().addMSecs(q->value(48).toInt()));   // Link Start Time
     line.setLinkLength(q->value(49).toInt());               // Link Length
     line.setLinkStartSlop(q->value(55).toInt());            // Link Start Slop
     line.setLinkEndSlop(q->value(56).toInt());              // Link End Slop
@@ -419,7 +437,7 @@ from %s left join CART on %s.CART_NUMBER=CART.NUMBER order by COUNT",
 	   q->value(40).toInt());
 */
 
-    log_line.push_back(line);
+    log_line.push_back(new RDLogLine(line));
   }
   delete q;
 
@@ -580,7 +598,7 @@ int RDLogEvent::validate(QString *report,const QDate &date)
 
 void RDLogEvent::refresh(int line)
 {
-  if(log_name.isEmpty()||log_line[line].cartNumber()==0) {
+  if(log_name.isEmpty()||log_line[line]->cartNumber()==0) {
     return;
   }
   QString sql=QString().sprintf("select CART.TYPE,CART.GROUP_NAME,CART.TITLE,\
@@ -594,50 +612,50 @@ void RDLogEvent::refresh(int line)
                                  GROUPS.COLOR from CART left join GROUPS \
                                  on CART.GROUP_NAME=GROUPS.NAME \
                                  where CART.NUMBER=%u",
-				log_line[line].cartNumber());
+				log_line[line]->cartNumber());
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     switch((RDCart::Type)q->value(0).toInt()) {
 	case RDCart::Audio:
-	  log_line[line].setType(RDLogLine::Cart);
+	  log_line[line]->setType(RDLogLine::Cart);
 	  break;
 	  
 	case RDCart::Macro:
-	  log_line[line].setType(RDLogLine::Macro);
+	  log_line[line]->setType(RDLogLine::Macro);
 	  break;
 	  
 	default:
 	  break;
     }	
-    log_line[line].
+    log_line[line]->
       setCartType((RDCart::Type)q->value(0).toInt());        // Cart Type
-    log_line[line].setGroupName(q->value(1).toString());       // Group Name
-    log_line[line].setTitle(q->value(2).toString());           // Title
-    log_line[line].setArtist(q->value(3).toString());          // Artist
-    log_line[line].setPublisher(q->value(16).toString());      // Publisher
-    log_line[line].setComposer(q->value(17).toString());       // Composer
-    log_line[line].setAlbum(q->value(4).toString());           // Album
-    log_line[line].setYear(q->value(5).toDate());              // Year
-    log_line[line].setLabel(q->value(6).toString());           // Label
-    log_line[line].setClient(q->value(7).toString());          // Client
-    log_line[line].setAgency(q->value(8).toString());          // Agency
-    log_line[line].setUserDefined(q->value(9).toString());     // User Defined
-    log_line[line].setUsageCode((RDCart::UsageCode)q->value(16).toInt());
-    log_line[line].setForcedLength(q->value(10).toUInt());   // Forced Length
-    log_line[line].setAverageSegueLength(q->value(19).toUInt());
-    log_line[line].setCutQuantity(q->value(11).toUInt());       // Cut Quantity
-    log_line[line].setLastCutPlayed(q->value(12).toUInt());  // Last Cut Played
-    log_line[line].
+    log_line[line]->setGroupName(q->value(1).toString());       // Group Name
+    log_line[line]->setTitle(q->value(2).toString());           // Title
+    log_line[line]->setArtist(q->value(3).toString());          // Artist
+    log_line[line]->setPublisher(q->value(16).toString());      // Publisher
+    log_line[line]->setComposer(q->value(17).toString());       // Composer
+    log_line[line]->setAlbum(q->value(4).toString());           // Album
+    log_line[line]->setYear(q->value(5).toDate());              // Year
+    log_line[line]->setLabel(q->value(6).toString());           // Label
+    log_line[line]->setClient(q->value(7).toString());          // Client
+    log_line[line]->setAgency(q->value(8).toString());          // Agency
+    log_line[line]->setUserDefined(q->value(9).toString());     // User Defined
+    log_line[line]->setUsageCode((RDCart::UsageCode)q->value(16).toInt());
+    log_line[line]->setForcedLength(q->value(10).toUInt());   // Forced Length
+    log_line[line]->setAverageSegueLength(q->value(19).toUInt());
+    log_line[line]->setCutQuantity(q->value(11).toUInt());       // Cut Quantity
+    log_line[line]->setLastCutPlayed(q->value(12).toUInt());  // Last Cut Played
+    log_line[line]->
       setPlayOrder((RDCart::PlayOrder)q->value(13).toUInt()); // Play Order
-    log_line[line].
+    log_line[line]->
       setEnforceLength(RDBool(q->value(14).toString()));     // Enforce Length
-    log_line[line].
+    log_line[line]->
       setPreservePitch(RDBool(q->value(15).toString()));     // Preserve Pitch
-    log_line[line].setValidity((RDCart::Validity)q->value(20).toInt());
-    log_line[line].setGroupColor(q->value(21).toString());  // Group Color
+    log_line[line]->setValidity((RDCart::Validity)q->value(20).toInt());
+    log_line[line]->setGroupColor(q->value(21).toString());  // Group Color
   }
   else {
-    log_line[line].setValidity(RDCart::NeverValid);
+    log_line[line]->setValidity(RDCart::NeverValid);
   }
   delete q;
   return;
@@ -654,27 +672,27 @@ void RDLogEvent::insert(int line,int num_lines,bool preserve_trans)
 {
   if(!preserve_trans) {
     if(line>0) {
-      log_line[line-1].setEndPoint(-1,RDLogLine::LogPointer);
-      log_line[line-1].setSegueStartPoint(-1,RDLogLine::LogPointer);
-      log_line[line-1].setSegueEndPoint(-1,RDLogLine::LogPointer);
+      log_line[line-1]->setEndPoint(-1,RDLogLine::LogPointer);
+      log_line[line-1]->setSegueStartPoint(-1,RDLogLine::LogPointer);
+      log_line[line-1]->setSegueEndPoint(-1,RDLogLine::LogPointer);
     }
     if(line<(size()-1)) {
-      log_line[line].setStartPoint(-1,RDLogLine::LogPointer);
-      log_line[line].setHasCustomTransition(false);
+      log_line[line]->setStartPoint(-1,RDLogLine::LogPointer);
+      log_line[line]->setHasCustomTransition(false);
     }
   }
   if(line<size()) {
-    vector<RDLogLine>::iterator it=log_line.begin()+line;
-    log_line.insert(it,num_lines,RDLogLine());
+    std::vector<RDLogLine *>::iterator it=log_line.begin()+line;
+    log_line.insert(it,num_lines,new RDLogLine());
     for(int i=line;i<(line+num_lines);i++) {
-      log_line[i].setId(++log_max_id);
+      log_line[i]->setId(++log_max_id);
     }
     return;
   }
   if(line>=size()) {
     for(int i=0;i<num_lines;i++) {
-      log_line.push_back(RDLogLine());
-      log_line.back().setId(++log_max_id);
+      log_line.push_back(new RDLogLine());
+      log_line.back()->setId(++log_max_id);
     }
     return;
   }
@@ -685,16 +703,19 @@ void RDLogEvent::remove(int line,int num_lines,bool preserve_trans)
 {
   if(!preserve_trans) {
   if(line>0) {
-    log_line[line-1].setEndPoint(-1,RDLogLine::LogPointer);
-    log_line[line-1].setSegueStartPoint(-1,RDLogLine::LogPointer);
-    log_line[line-1].setSegueEndPoint(-1,RDLogLine::LogPointer);
+    log_line[line-1]->setEndPoint(-1,RDLogLine::LogPointer);
+    log_line[line-1]->setSegueStartPoint(-1,RDLogLine::LogPointer);
+    log_line[line-1]->setSegueEndPoint(-1,RDLogLine::LogPointer);
   }
   if(line<((int)log_line.size()-num_lines)) {
-    log_line[line+num_lines].setStartPoint(-1,RDLogLine::LogPointer);
-    log_line[line+num_lines].setHasCustomTransition(false);
+    log_line[line+num_lines]->setStartPoint(-1,RDLogLine::LogPointer);
+    log_line[line+num_lines]->setHasCustomTransition(false);
   }
   }  
-  vector<RDLogLine>::iterator it=log_line.begin()+line;
+  for(int i=line;i<(line+num_lines);i++) {
+    delete log_line[i];
+  }
+  std::vector<RDLogLine *>::iterator it=log_line.begin()+line;
   log_line.erase(it,it+num_lines);
 }
 
@@ -820,7 +841,6 @@ bool RDLogEvent::blockLength(int *nominal_length,int *actual_length,int line)
   // Find Block End
   //
   for(int i=line+1;i<size();i++) {
-//    if(logLine(i)->postPoint()) {
     if(logLine(i)->timeType()==RDLogLine::Hard) {
       end_time=logLine(i)->startTime(RDLogLine::Logged);
       end_line=i;
@@ -894,15 +914,15 @@ RDLogLine *RDLogEvent::logLine(int line)
   if((line<0)||((unsigned)line>=log_line.size())) {
     return NULL;
   }
-  return &log_line[line];
+  return log_line[line];
 }
 
 
 RDLogLine *RDLogEvent::loglineById(int id)
 {
   for(int i=0;i<size();i++) {
-    if(log_line[i].id()==id) {
-      return &log_line[i];
+    if(log_line[i]->id()==id) {
+      return log_line[i];
     }
   }
   return NULL;
@@ -912,7 +932,7 @@ RDLogLine *RDLogEvent::loglineById(int id)
 int RDLogEvent::lineById(int id) const
 {
   for(int i=0;i<size();i++) {
-    if(log_line[i].id()==id) {
+    if(log_line[i]->id()==id) {
       return i;
     }
   }
@@ -923,8 +943,8 @@ int RDLogEvent::lineById(int id) const
 int RDLogEvent::nextTimeStart(QTime after)
 {
   for(unsigned i=0;i<log_line.size();i++) {
-    if((log_line[i].timeType()==RDLogLine::Hard)&&
-       (log_line[i].startTime(RDLogLine::Logged)>after)) {
+    if((log_line[i]->timeType()==RDLogLine::Hard)&&
+       (log_line[i]->startTime(RDLogLine::Logged)>after)) {
       return i;
     }
   }
@@ -981,8 +1001,8 @@ int RDLogEvent::nextId() const
 {
   int id=-1;
   for(int i=0;i<size();i++) {
-    if(log_line[i].id()>id) {
-      id=log_line[i].id();
+    if(log_line[i]->id()>id) {
+      id=log_line[i]->id();
     }
   }
   return id+1;
@@ -993,8 +1013,8 @@ int RDLogEvent::nextLinkId() const
 {
   int id=-1;
   for(int i=0;i<size();i++) {
-    if(log_line[i].linkId()>id) {
-      id=log_line[i].linkId();
+    if(log_line[i]->linkId()>id) {
+      id=log_line[i]->linkId();
     }
   }
   return id+1;
@@ -1006,7 +1026,7 @@ void RDLogEvent::SaveLine(int line)
   QString sql;
   RDSqlQuery *q;
   sql=QString().sprintf("insert into %s set ID=%d,COUNT=%d,\
-                         CART_NUMBER=%u,START_TIME=\"%s\",TIME_TYPE=%d,\
+                         CART_NUMBER=%u,START_TIME=%d,TIME_TYPE=%d,\
                          TRANS_TYPE=%d,START_POINT=%d,END_POINT=%d,\
                          SEGUE_START_POINT=%d,SEGUE_END_POINT=%d,TYPE=%d,\
                          COMMENT=\"%s\",LABEL=\"%s\",GRACE_TIME=%d,\
@@ -1015,60 +1035,59 @@ void RDLogEvent::SaveLine(int line)
                          EXT_ANNC_TYPE=\"%s\",EXT_CART_NAME=\"%s\",\
                          FADEUP_POINT=%d,FADEUP_GAIN=%d,FADEDOWN_POINT=%d,\
                          FADEDOWN_GAIN=%d,SEGUE_GAIN=%d,\
-                         LINK_EVENT_NAME=\"%s\",LINK_START_TIME=\"%s\",\
+                         LINK_EVENT_NAME=\"%s\",LINK_START_TIME=%d,\
                          LINK_LENGTH=%d,LINK_ID=%d,LINK_EMBEDDED=\"%s\",\
                          ORIGIN_USER=\"%s\",ORIGIN_DATETIME=\"%s\",\
                          LINK_START_SLOP=%d,LINK_END_SLOP=%d,\
                          DUCK_UP_GAIN=%d,DUCK_DOWN_GAIN=%d",
 			(const char *)log_name,
-			log_line[line].id(),
+			log_line[line]->id(),
 			line,
-			log_line[line].cartNumber(),
-			(const char *)log_line[line].
-			startTime(RDLogLine::Logged).toString("hh:mm:ss"),
-			(int)log_line[line].timeType(),
-			(int)log_line[line].transType(),
-			log_line[line].startPoint(RDLogLine::LogPointer),
-			log_line[line].endPoint(RDLogLine::LogPointer),
-			log_line[line].segueStartPoint(RDLogLine::LogPointer),
-			log_line[line].segueEndPoint(RDLogLine::LogPointer),
-			log_line[line].type(),
+			log_line[line]->cartNumber(),
+			QTime().msecsTo(log_line[line]->
+					startTime(RDLogLine::Logged)),
+			(int)log_line[line]->timeType(),
+			(int)log_line[line]->transType(),
+			log_line[line]->startPoint(RDLogLine::LogPointer),
+			log_line[line]->endPoint(RDLogLine::LogPointer),
+			log_line[line]->segueStartPoint(RDLogLine::LogPointer),
+			log_line[line]->segueEndPoint(RDLogLine::LogPointer),
+			log_line[line]->type(),
 			(const char *)
-			RDEscapeString(log_line[line].markerComment()),
+			RDEscapeString(log_line[line]->markerComment()),
 			(const char *)
-			RDEscapeString(log_line[line].markerLabel()),
-			log_line[line].graceTime(),
-			log_line[line].source(),
-			(const char *)log_line[line].extStartTime().
+			RDEscapeString(log_line[line]->markerLabel()),
+			log_line[line]->graceTime(),
+			log_line[line]->source(),
+			(const char *)log_line[line]->extStartTime().
 			toString("hh:mm:ss"),
-			log_line[line].extLength(),
-			(const char *)RDEscapeString(log_line[line].extData()),
+			log_line[line]->extLength(),
+			(const char *)RDEscapeString(log_line[line]->extData()),
 			(const char *)
-			RDEscapeString(log_line[line].extEventId()),
+			RDEscapeString(log_line[line]->extEventId()),
 			(const char *)
-			RDEscapeString(log_line[line].extAnncType()),
+			RDEscapeString(log_line[line]->extAnncType()),
 			(const char *)
-			RDEscapeString(log_line[line].extCartName()),
-			log_line[line].fadeupPoint(RDLogLine::LogPointer),
-			log_line[line].fadeupGain(),
-			log_line[line].fadedownPoint(RDLogLine::LogPointer),
-			log_line[line].fadedownGain(),
-			log_line[line].segueGain(),
+			RDEscapeString(log_line[line]->extCartName()),
+			log_line[line]->fadeupPoint(RDLogLine::LogPointer),
+			log_line[line]->fadeupGain(),
+			log_line[line]->fadedownPoint(RDLogLine::LogPointer),
+			log_line[line]->fadedownGain(),
+			log_line[line]->segueGain(),
 			(const char *)
-			RDEscapeString(log_line[line].linkEventName()),
-			(const char *)log_line[line].linkStartTime().
-			toString("hh:mm:ss"),
-			log_line[line].linkLength(),
-			log_line[line].linkId(),
-			(const char *)RDYesNo(log_line[line].linkEmbedded()),
+			RDEscapeString(log_line[line]->linkEventName()),
+			QTime().msecsTo(log_line[line]->linkStartTime()),
+			log_line[line]->linkLength(),
+			log_line[line]->linkId(),
+			(const char *)RDYesNo(log_line[line]->linkEmbedded()),
 			(const char *)
-			RDEscapeString(log_line[line].originUser()),
-			(const char *)log_line[line].originDateTime().
+			RDEscapeString(log_line[line]->originUser()),
+			(const char *)log_line[line]->originDateTime().
 			toString("yyyy-MM-dd hh:mm:ss"),
-			log_line[line].linkStartSlop(),
-			log_line[line].linkEndSlop(),
-                        log_line[line].duckUpGain(),
-                        log_line[line].duckDownGain());
+			log_line[line]->linkStartSlop(),
+			log_line[line]->linkEndSlop(),
+                        log_line[line]->duckUpGain(),
+                        log_line[line]->duckDownGain());
 
   // printf("SQL: %s\n",(const char *)sql);
   q=new RDSqlQuery(sql);
@@ -1078,8 +1097,8 @@ void RDLogEvent::SaveLine(int line)
 
 void RDLogEvent::LoadNowNext()
 {
-  vector<QString> groups;
-  vector<bool> now_nexts;
+  std::vector<QString> groups;
+  std::vector<bool> now_nexts;
 
   //
   // Load the Lookup Table
@@ -1093,8 +1112,8 @@ void RDLogEvent::LoadNowNext()
 
   for(unsigned i=0;i<log_line.size();i++) {
     for(unsigned j=0;j<groups.size();j++) {
-      if(log_line[i].groupName()==groups[j]) {
-	log_line[i].setNowNextEnabled(now_nexts[j]);
+      if(log_line[i]->groupName()==groups[j]) {
+	log_line[i]->setNowNextEnabled(now_nexts[j]);
       }
     }
   }
