@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsound_panel.cpp,v 1.53 2008-07-15 18:29:01 fredg Exp $
+//      $Id: rdsound_panel.cpp,v 1.62 2011/05/18 18:57:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@
 #include <rdcut.h>
 #include <rdedit_panel_name.h>
 #include <rdescape_string.h>
-
+#include <rdconf.h>
 
 RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
 			   int user_panels,bool flash,
@@ -79,6 +79,10 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
     panel_port[i]=-1;
   }
   panel_cart_dialog=cart_dialog;
+  for(int i=0;i<PANEL_MAX_OUTPUTS;i++) {
+    panel_timescaling_supported[i]=false;
+  }
+  panel_onair_flag=false;
 
   //
   // Create Fonts
@@ -99,6 +103,7 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   //
   panel_selector_box=new RDComboBox(this,"panel_selector_box");
   panel_selector_box->setFont(button_font);
+  panel_selector_box->addIgnoredKey(Qt::Key_Space);
   panel_selector_box->
     setGeometry((15+PANEL_BUTTON_SIZE_X)*(panel_button_columns-5),
 		(15+PANEL_BUTTON_SIZE_Y)*panel_button_rows,
@@ -111,13 +116,13 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   if(panel_station_panels>0) {
     panel_number=0;
     panel_type=RDAirPlayConf::StationPanel;
-    panel_buttons[0].show();
+    panel_buttons[0]->show();
   }
   else {
     if(panel_user_panels>0) {
       panel_number=0;
       panel_type=RDAirPlayConf::UserPanel;
-      panel_buttons[0].show();
+      panel_buttons[0]->show();
     }
     else {
       setDisabled(true);
@@ -195,6 +200,12 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   connect(panel_cae,SIGNAL(timescalingSupported(int,bool)),
 	  this,SLOT(timescalingSupportedData(int,bool)));
 
+  //
+  // RIPC Setup
+  //
+  connect(panel_ripc,SIGNAL(onairFlagChanged(bool)),
+	  this,SLOT(onairFlagChangedData(bool)));
+
   //
   // Load Panel Names
   //
@@ -227,6 +238,14 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
 }
 
 
+RDSoundPanel::~RDSoundPanel()
+{
+  for(unsigned i=0;i<panel_buttons.size();i++) {
+    delete panel_buttons[i];
+  }
+}
+
+
 QSize RDSoundPanel::sizeHint() const
 {
   return QSize(panel_button_columns*(PANEL_BUTTON_SIZE_X+15),
@@ -304,7 +323,7 @@ void RDSoundPanel::setButton(RDAirPlayConf::PanelType type,int panel,
   QString str;
 
   RDPanelButton *button=
-    panel_buttons[PanelOffset(type,panel)].panelButton(row,col);
+    panel_buttons[PanelOffset(type,panel)]->panelButton(row,col);
   if(button->playDeck()!=NULL) {
     return;
   }
@@ -345,7 +364,8 @@ void RDSoundPanel::play(RDAirPlayConf::PanelType type,int panel,
 			int row, int col,RDLogLine::StartSource src,int mport,
                         bool pause_when_finished)
 {
-  PlayButton(type,panel,row,col,src,panel_playmode_box->currentItem()==1,mport,pause_when_finished);
+  PlayButton(type,panel,row,col,src,panel_playmode_box->currentItem()==1,
+	     mport,pause_when_finished);
 }
 
 
@@ -378,14 +398,14 @@ void RDSoundPanel::duckVolume(RDAirPlayConf::PanelType type,int panel,int row,in
     for(int i=0;i<panel_button_columns;i++) {
 	    for(int j=0;j<panel_button_rows;j++) {
       RDPlayDeck *deck=
-        panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->playDeck();
+        panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->playDeck();
       if((row==j || row==-1) && (col==i || col==-1)) {
 	if(mport==-1) {
-	  panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->setDuckVolume(level);
+	  panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->setDuckVolume(level);
 	}    
         if(deck!=NULL) {
           if(edit_mport==-1 || 
-             edit_mport==panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->
+             edit_mport==panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->
                      outputText().toInt()) {
 	    deck->duckVolume(level,fade);
           }
@@ -435,10 +455,10 @@ void RDSoundPanel::setActionMode(RDAirPlayConf::ActionMode mode)
       if(i<(unsigned)panel_station_panels &&
           (!panel_config_panels) &&   
           (mode==RDAirPlayConf::AddTo || mode==RDAirPlayConf::CopyTo || mode==RDAirPlayConf::DeleteFrom)) {
-        panel_buttons[i].setActionMode(RDAirPlayConf::Normal);
+        panel_buttons[i]->setActionMode(RDAirPlayConf::Normal);
         }
       else {
-        panel_buttons[i].setActionMode(panel_action_mode);
+        panel_buttons[i]->setActionMode(panel_action_mode);
         }
       }
     }
@@ -483,7 +503,7 @@ void RDSoundPanel::changeUser()
   panel_user=new RDUser(panel_ripc->user());
   panel_config_panels=panel_user->configPanels();
   LoadPanels();
-  panel_buttons[PanelOffset(panel_type,panel_number)].show();
+  panel_buttons[PanelOffset(panel_type,panel_number)]->show();
 
   //
   // Remove Old Panel Names
@@ -536,7 +556,7 @@ void RDSoundPanel::tickClock()
 
 void RDSoundPanel::panelActivatedData(int n)
 {
-  panel_buttons[PanelOffset(panel_type,panel_number)].hide();
+  panel_buttons[PanelOffset(panel_type,panel_number)]->hide();
   if(n<panel_station_panels) {
     panel_type=RDAirPlayConf::StationPanel;
     panel_number=n;
@@ -545,7 +565,7 @@ void RDSoundPanel::panelActivatedData(int n)
     panel_type=RDAirPlayConf::UserPanel;
     panel_number=n-panel_station_panels;
   }
-  panel_buttons[PanelOffset(panel_type,panel_number)].show();
+  panel_buttons[PanelOffset(panel_type,panel_number)]->show();
 }
 
 
@@ -604,29 +624,35 @@ void RDSoundPanel::buttonMapperData(int id)
 
   switch(panel_action_mode) {
       case RDAirPlayConf::CopyFrom:
-	if((cartnum=panel_buttons[PanelOffset(panel_type,panel_number)].
+	if((cartnum=panel_buttons[PanelOffset(panel_type,panel_number)]->
 	    panelButton(row,col)->cart())>0) {
 	  emit selectClicked(cartnum,0,0);
 	}
 	break;
 	
       case RDAirPlayConf::CopyTo:
-         if(panel_buttons[PanelOffset(panel_type,panel_number)].panelButton(row,col)->playDeck()==NULL
-             && ((panel_type==RDAirPlayConf::UserPanel) || panel_config_panels)) { 
+         if(panel_buttons[PanelOffset(panel_type,panel_number)]->
+	    panelButton(row,col)->playDeck()==NULL
+             && ((panel_type==RDAirPlayConf::UserPanel) || 
+		 panel_config_panels)) { 
 	   emit selectClicked(0,row,col);
            }
 	break;
 	
       case RDAirPlayConf::AddTo:
-         if(panel_buttons[PanelOffset(panel_type,panel_number)].panelButton(row,col)->playDeck()==NULL
-             && ((panel_type==RDAirPlayConf::UserPanel) || panel_config_panels)) { 
+         if(panel_buttons[PanelOffset(panel_type,panel_number)]->
+	    panelButton(row,col)->playDeck()==NULL
+             && ((panel_type==RDAirPlayConf::UserPanel) || 
+		 panel_config_panels)) { 
 	   emit selectClicked(0,row,col);
            }
 	break;
 	
       case RDAirPlayConf::DeleteFrom:
-         if(panel_buttons[PanelOffset(panel_type,panel_number)].panelButton(row,col)->playDeck()==NULL
-             && ((panel_type==RDAirPlayConf::UserPanel) || panel_config_panels)) { 
+         if(panel_buttons[PanelOffset(panel_type,panel_number)]->
+	    panelButton(row,col)->playDeck()==NULL
+             && ((panel_type==RDAirPlayConf::UserPanel) || 
+		 panel_config_panels)) { 
 	   emit selectClicked(0,row,col);
            }
 	break;
@@ -639,7 +665,7 @@ void RDSoundPanel::buttonMapperData(int id)
 	    return;
 	  }
 	  if(panel_button_dialog->
-	     exec(panel_buttons[PanelOffset(panel_type,panel_number)].
+	     exec(panel_buttons[PanelOffset(panel_type,panel_number)]->
 		  panelButton(row,col),panel_playmode_box->currentItem()==1)
 	     ==0) {
 	    SaveButton(panel_type,panel_number,row,col);
@@ -647,21 +673,11 @@ void RDSoundPanel::buttonMapperData(int id)
 	}
 	else {
 	  RDPanelButton *button=
-	    panel_buttons[PanelOffset(panel_type,panel_number)].
+	    panel_buttons[PanelOffset(panel_type,panel_number)]->
 	    panelButton(row,col);
 	  RDPlayDeck *deck=button->playDeck();
 	  if(panel_reset_mode) {
-//	    if(deck!=NULL) {
-//	      switch(deck->state()) {
-//		  case RDPlayDeck::Playing:
-//		  case RDPlayDeck::Paused:
-		    StopButton(panel_type,panel_number,row,col);
-//		    break;
-		    
-//		  default:
-//		    break;
-//	      }
-//	    }
+	    StopButton(panel_type,panel_number,row,col);
 	  }
 	  else {
 	    if(deck==NULL) {
@@ -745,35 +761,44 @@ void RDSoundPanel::timescalingSupportedData(int card,bool state)
 
 void RDSoundPanel::panelSetupData()
 {
-  QString sql;
-  RDSqlQuery *q;
-  int cutpt=panel_selector_box->currentText().find(" ");
-  if(panel_selector_box->currentText().left(5)==tr("Panel")) {
-    cutpt=-1;
-  }
-  QString panel_name=panel_selector_box->currentText().right(panel_selector_box->currentText().length()-cutpt-1);
-  RDEditPanelName *edn=new RDEditPanelName(&panel_name);
-  if(edn->exec()==0) {
-    panel_selector_box->
-      setCurrentText(QString().sprintf("[%s] %s",
+  if(panel_user->configPanels()||(panel_type==RDAirPlayConf::UserPanel)) {
+    QString sql;
+    RDSqlQuery *q;
+    int cutpt=panel_selector_box->currentText().find(" ");
+    if(panel_selector_box->currentText().left(5)==tr("Panel")) {
+      cutpt=-1;
+    }
+    QString panel_name=panel_selector_box->currentText().
+      right(panel_selector_box->currentText().length()-cutpt-1);
+    RDEditPanelName *edn=new RDEditPanelName(&panel_name);
+    if(edn->exec()==0) {
+      panel_selector_box->
+	setCurrentText(QString().sprintf("[%s] %s",
 	     (const char *)PanelTag(panel_selector_box->currentItem()),
-	     (const char *)panel_name));
-    sql=QString().sprintf("delete from %s where \
+					 (const char *)panel_name));
+      sql=QString().sprintf("delete from %s where \
                            (TYPE=%d)&&(OWNER=\"%s\")&&(PANEL_NO=%d)",
-			  (const char *)panel_name_tablename,
-			  panel_type,(const char *)PanelOwner(panel_type),
-			  panel_number);
-    q=new RDSqlQuery(sql);
-    delete q;
-    sql=QString().sprintf("insert into %s set TYPE=%d,OWNER=\"%s\",\
+			    (const char *)panel_name_tablename,
+			    panel_type,(const char *)PanelOwner(panel_type),
+			    panel_number);
+      q=new RDSqlQuery(sql);
+      delete q;
+      sql=QString().sprintf("insert into %s set TYPE=%d,OWNER=\"%s\",\
                            PANEL_NO=%d,NAME=\"%s\"",
-			  (const char *)panel_name_tablename,panel_type,
-			  (const char *)PanelOwner(panel_type),panel_number,
-			  (const char *)RDEscapeString(panel_name));
-    q=new RDSqlQuery(sql);
-    delete q;
+			    (const char *)panel_name_tablename,panel_type,
+			    (const char *)PanelOwner(panel_type),panel_number,
+			    (const char *)RDEscapeString(panel_name));
+      q=new RDSqlQuery(sql);
+      delete q;
+    }
+    delete edn;
   }
-  delete edn;
+}
+
+
+void RDSoundPanel::onairFlagChangedData(bool state)
+{
+  panel_onair_flag=state;
 }
 
 
@@ -786,9 +811,9 @@ void RDSoundPanel::PlayButton(RDAirPlayConf::PanelType type,int panel,
   
   for(int i=0;i<panel_button_columns;i++) {
     for(int j=0;j<panel_button_rows;j++) {
-      if(panel_buttons[PanelOffset(type,panel)].
+      if(panel_buttons[PanelOffset(type,panel)]->
 	 panelButton(j,i)->cart()>0 && 
-         panel_buttons[PanelOffset(type,panel)].
+         panel_buttons[PanelOffset(type,panel)]->
 	 panelButton(j,i)->state()==false) {
         if(edit_col==-1 || col==i) {
 	  edit_col=i;
@@ -804,7 +829,7 @@ void RDSoundPanel::PlayButton(RDAirPlayConf::PanelType type,int panel,
   }
   
   RDPanelButton *button=
-    panel_buttons[PanelOffset(type,panel)].panelButton(edit_row,edit_col);
+    panel_buttons[PanelOffset(type,panel)]->panelButton(edit_row,edit_col);
   RDPlayDeck *deck=button->playDeck();
   if(deck!=NULL) {
     deck->play(deck->currentPosition());
@@ -882,7 +907,8 @@ bool RDSoundPanel::PlayAudio(RDPanelButton *button,RDCart *cart,bool hookmode,in
   button->playDeck()->setCard(panel_card[button->output()]);
   button->playDeck()->setPort(panel_port[button->output()]);
   button->playDeck()->duckVolume(button->duckVolume(),0);
-  if(panel_timescaling_supported&&cart->enforceLength()) {
+  if(panel_timescaling_supported[panel_card[button->output()]]&&
+     cart->enforceLength()) {
     timescale=true;
   }
   logline.loadCart(cart->number(),RDLogLine::Play,0,timescale);
@@ -913,9 +939,9 @@ bool RDSoundPanel::PlayAudio(RDPanelButton *button,RDCart *cart,bool hookmode,in
   int segue_start=-1;
   int segue_end=-1;
   if(hookmode&&(logline.hookStartPoint()>=0)&&(logline.hookEndPoint()>=0)) {
-    start_pos=logline.hookStartPoint();
-    segue_start=logline.hookEndPoint();
-    segue_end=logline.hookEndPoint();
+    start_pos=logline.hookStartPoint()-logline.startPoint();
+    segue_start=logline.hookEndPoint()-logline.startPoint();
+    segue_end=logline.hookEndPoint()-logline.startPoint();
   }
 
   //
@@ -957,7 +983,7 @@ void RDSoundPanel::PlayMacro(RDPanelButton *button,RDCart *cart)
   }
   if(button->pauseWhenFinished() && panel_pause_enabled) {
     button->setState(true);
-    button->WriteKeycap(-1);
+    button->resetCounter();
     button->setColor(RDPANEL_PAUSED_BACKGROUND_COLOR);
   }
 }
@@ -969,13 +995,14 @@ void RDSoundPanel::PauseButton(RDAirPlayConf::PanelType type,int panel,
 	for(int i=0;i<panel_button_columns;i++) {
 		for(int j=0;j<panel_button_rows;j++) {
       RDPlayDeck *deck=
-        panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->playDeck();
+        panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->playDeck();
       if(deck!=NULL && (row==j || row==-1) && (col==i || col==-1)) {
         if(mport==-1 || 
-           mport==panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->outputText().toInt()) {
+           mport==panel_buttons[PanelOffset(type,panel)]->
+	   panelButton(j,i)->outputText().toInt()) {
           deck->pause();
 
-          panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->
+          panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->
              setStartTime(QTime());
           }
        }
@@ -995,18 +1022,18 @@ void RDSoundPanel::StopButton(RDAirPlayConf::PanelType type,int panel,
     for(int i=0;i<panel_button_columns;i++) {
 	    for(int j=0;j<panel_button_rows;j++) {
       RDPlayDeck *deck=
-        panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->playDeck();
+        panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->playDeck();
       if((row==j || row==-1) && (col==i || col==-1)) {
         if(deck!=NULL) {
           if(edit_mport==-1 || 
-             edit_mport==panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->
+             edit_mport==panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->
                      outputText().toInt()) {
             if(panel_pause_enabled) {
-              panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->
+              panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->
                     setPauseWhenFinished(pause_when_finished);
               }
             else {
-              panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->
+              panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->
                     setPauseWhenFinished(false);
               }
             switch(deck->state()) {
@@ -1026,10 +1053,10 @@ void RDSoundPanel::StopButton(RDAirPlayConf::PanelType type,int panel,
         }
       else {
         if(!pause_when_finished && panel_pause_enabled) {
-          panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->setState(false); 
-          panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->
+          panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->setState(false); 
+          panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->
               setPauseWhenFinished(false); 
-          panel_buttons[PanelOffset(type,panel)].panelButton(j,i)->reset(); 
+          panel_buttons[PanelOffset(type,panel)]->panelButton(j,i)->reset(); 
           }
         }
       }
@@ -1070,34 +1097,37 @@ void RDSoundPanel::StopButton(RDPlayDeck *deck)
 
 void RDSoundPanel::LoadPanels()
 {
+  for(unsigned i=0;i<panel_buttons.size();i++) {
+    delete panel_buttons[i];
+  }
   panel_buttons.clear();
 
   //
   // Load Buttons
   //
   for(int i=0;i<panel_station_panels;i++) {
-    panel_buttons.push_back(RDButtonPanel(panel_button_columns,
-					  panel_button_rows,
-					  panel_station,panel_flash,this));
+    panel_buttons.push_back(new RDButtonPanel(panel_button_columns,
+					      panel_button_rows,
+					      panel_station,panel_flash,this));
     for(int j=0;j<panel_button_rows;j++) {
       for(int k=0;k<panel_button_columns;k++) {
-	connect(panel_buttons.back().panelButton(j,k),SIGNAL(clicked()),
+	connect(panel_buttons.back()->panelButton(j,k),SIGNAL(clicked()),
 		panel_mapper,SLOT(map()));
-	panel_mapper->setMapping(panel_buttons.back().panelButton(j,k),
+	panel_mapper->setMapping(panel_buttons.back()->panelButton(j,k),
 			   j*panel_button_columns+k);
       }
     }
     LoadPanel(RDAirPlayConf::StationPanel,i);
   }
   for(int i=0;i<panel_user_panels;i++) {
-    panel_buttons.push_back(RDButtonPanel(panel_button_columns,
-					  panel_button_rows,
-					  panel_station,panel_flash,this));
+    panel_buttons.push_back(new RDButtonPanel(panel_button_columns,
+					      panel_button_rows,
+					      panel_station,panel_flash,this));
     for(int j=0;j<panel_button_rows;j++) {
       for(int k=0;k<panel_button_columns;k++) {
-	connect(panel_buttons.back().panelButton(j,k),SIGNAL(clicked()),
+	connect(panel_buttons.back()->panelButton(j,k),SIGNAL(clicked()),
 		panel_mapper,SLOT(map()));
-	panel_mapper->setMapping(panel_buttons.back().panelButton(j,k),
+	panel_mapper->setMapping(panel_buttons.back()->panelButton(j,k),
 			   j*panel_button_columns+k);
       }
     }
@@ -1149,44 +1179,44 @@ void RDSoundPanel::LoadPanel(RDAirPlayConf::PanelType type,int panel)
 				(const char *)panel_tablename);
   RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
-    if(panel_buttons[offset].panelButton(q->value(0).toInt(),
+    if(panel_buttons[offset]->panelButton(q->value(0).toInt(),
 	      q->value(1).toInt())->playDeck()==NULL) {
-      panel_buttons[offset].
+      panel_buttons[offset]->
 	panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	setText(q->value(2).toString());
-      panel_buttons[offset].
+      panel_buttons[offset]->
 	panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	setCart(q->value(3).toInt());
-      panel_buttons[offset].
+      panel_buttons[offset]->
 	panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	setLength(false,q->value(5).toInt());
-      panel_buttons[offset].
+      panel_buttons[offset]->
 	panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	setLength(true,q->value(6).toInt());
       if((panel_playmode_box!=NULL)&&(panel_playmode_box->currentItem()==1)&&
 	 (q->value(6).toUInt()>0)) {
-	panel_buttons[offset].
+	panel_buttons[offset]->
 	  panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	  setActiveLength(q->value(6).toInt());
       }
       else {
-	panel_buttons[offset].
+	panel_buttons[offset]->
 	  panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	  setActiveLength(q->value(5).toInt());
       }
       if(q->value(4).toString().isEmpty()) {
-	panel_buttons[offset].
+	panel_buttons[offset]->
 	  panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	  setColor(palette().active().background());
-	panel_buttons[offset].
+	panel_buttons[offset]->
 	  panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	  setDefaultColor(palette().active().background());
       }
       else {
-	panel_buttons[offset].
+	panel_buttons[offset]->
 	  panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	  setColor(QColor(q->value(4).toString()));
-	panel_buttons[offset].
+	panel_buttons[offset]->
 	  panelButton(q->value(0).toInt(),q->value(1).toInt())->
 	  setDefaultColor(QColor(q->value(4).toString()));
       }
@@ -1238,12 +1268,12 @@ void RDSoundPanel::SaveButton(RDAirPlayConf::PanelType type,
     CART=%d,DEFAULT_COLOR=\"%s\" where (TYPE=%d)&&(OWNER=\"%s\")&&\
     (PANEL_NO=%d)&&(ROW_NO=%d)&&(COLUMN_NO=%d)",
 			   (const char *)panel_tablename,
-			   (const char *)RDEscapeString(panel_buttons[offset].
+			   (const char *)RDEscapeString(panel_buttons[offset]->
 							panelButton(row,col)->
 							text().utf8()),
-			   panel_buttons[PanelOffset(panel_type,panel_number)].
+			   panel_buttons[PanelOffset(panel_type,panel_number)]->
 			   panelButton(row,col)->cart(),
-			   (const char *)panel_buttons[offset].
+			   (const char *)panel_buttons[offset]->
 			   panelButton(row,col)->defaultColor().
 			   name(),
 			   type,
@@ -1273,12 +1303,12 @@ void RDSoundPanel::SaveButton(RDAirPlayConf::PanelType type,
 			   panel,
 			   row,
 			   col,
-			   (const char *)RDEscapeString(panel_buttons[offset].
+			   (const char *)RDEscapeString(panel_buttons[offset]->
 							panelButton(row,col)->
 							text().utf8()),
-			   panel_buttons[PanelOffset(panel_type,panel_number)].
+			   panel_buttons[PanelOffset(panel_type,panel_number)]->
 			   panelButton(row,col)->cart(),
-			   (const char *)panel_buttons[offset].
+			   (const char *)panel_buttons[offset]->
 			   panelButton(row,col)->
 			   defaultColor().name());
     q=new RDSqlQuery(sql1);
@@ -1353,7 +1383,7 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
 
   sql=QString().sprintf("select CART.TITLE,CART.ARTIST,CART.PUBLISHER,\
                          CART.COMPOSER,CART.USAGE_CODE,CUTS.ISRC,\
-                         CART.ALBUM,CART.LABEL \
+                         CART.ALBUM,CART.LABEL,CUTS.ISCI \
                          from CART left join CUTS \
                          on CART.NUMBER=CUTS.CART_NUMBER \
                          where CUTS.CUT_NAME=\"%s\"",
@@ -1367,7 +1397,7 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
                          CUT_NUMBER=%d,TITLE=\"%s\",ARTIST=\"%s\",\
                          PUBLISHER=\"%s\",COMPOSER=\"%s\",USAGE_CODE=%d,\
                          ISRC=\"%s\",START_SOURCE=%d,ALBUM=\"%s\",\
-                         LABEL=\"%s\"",
+                         LABEL=\"%s\",ISCI=\"%s\",ONAIR_FLAG=\"%s\"",
 			  (const char *)panel_svcname,
 			  button->startTime().msecsTo(datetime.time()),
 			  button->cart(),
@@ -1387,7 +1417,9 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
 			  (const char *)q->value(5).toString(),
 			  button->startSource(),
 			  (const char *)RDEscapeString(q->value(6).toString()),
-			  (const char *)RDEscapeString(q->value(7).toString()));
+			  (const char *)RDEscapeString(q->value(7).toString()),
+			  (const char *)RDEscapeString(q->value(8).toString()),
+			  (const char *)RDYesNo(panel_onair_flag));
     delete q;
     q=new RDSqlQuery(sql);
   }
@@ -1404,7 +1436,7 @@ void RDSoundPanel::LogTrafficMacro(RDPanelButton *button)
   sql=QString().sprintf("select TITLE,ARTIST,PUBLISHER,\
                          COMPOSER,USAGE_CODE,FORCED_LENGTH,\
                          ALBUM,LABEL from CART where NUMBER=%u",
-			(const char *)button->cart());
+			button->cart());
   q=new RDSqlQuery(sql);
   if(q->first()) {
     sql=QString().sprintf("insert into `%s_SRT` set\
@@ -1414,7 +1446,7 @@ void RDSoundPanel::LogTrafficMacro(RDPanelButton *button)
                          TITLE=\"%s\",ARTIST=\"%s\",\
                          PUBLISHER=\"%s\",COMPOSER=\"%s\",USAGE_CODE=%d,\
                          START_SOURCE=%d,ALBUM=\"%s\",\
-                         LABEL=\"%s\"",
+                         LABEL=\"%s\",ONAIR_FLAG=\"%s\"",
 			  (const char *)panel_svcname,
 			  q->value(5).toUInt(),
 			  button->cart(),
@@ -1431,7 +1463,8 @@ void RDSoundPanel::LogTrafficMacro(RDPanelButton *button)
 			  q->value(4).toInt(),
 			  button->startSource(),
 			  (const char *)RDEscapeString(q->value(6).toString()),
-			  (const char *)RDEscapeString(q->value(7).toString()));
+			  (const char *)RDEscapeString(q->value(7).toString()),
+			  (const char *)RDYesNo(panel_onair_flag));
     delete q;
     q=new RDSqlQuery(sql);
     delete q;
@@ -1510,7 +1543,7 @@ void RDSoundPanel::Stopped(int id)
   if(panel_active_buttons[id]->pauseWhenFinished()) {
     panel_active_buttons[id]->setState(true);
     panel_active_buttons[id]->setColor(RDPANEL_PAUSED_BACKGROUND_COLOR);
-    panel_active_buttons[id]->WriteKeycap(-1);
+    panel_active_buttons[id]->resetCounter();
     }
   else {
     panel_active_buttons[id]->setState(false);
