@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdwavepainter.cpp,v 1.8 2007-12-29 18:16:10 fredg Exp $
+//      $Id: rdwavepainter.cpp,v 1.12 2011/05/03 17:54:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,40 +25,51 @@
 #include <qpointarray.h>
 #include <qpixmap.h>
 #include <qfile.h>
+#include <qmessagebox.h>
 
 #include <rdwavepainter.h>
 
 
-RDWavePainter::RDWavePainter(const QPaintDevice *pd,const QString &wavname)
-  : QPainter(pd), RDWaveFile(wavname)
+RDWavePainter::RDWavePainter(const QPaintDevice *pd,RDCut *cut,
+			     RDStation *station,RDUser *user)
+  : QPainter(pd)
 {
-  wave_name=wavname;
-  RDWaveFile::openWave();
+  wave_cut=cut;
+  wave_station=station;
+  wave_user=user;
+  wave_peaks=NULL;
+  LoadWave();
 }
 
 
-RDWavePainter::RDWavePainter()
+RDWavePainter::RDWavePainter(RDStation *station,RDUser *user)
 {
+  wave_cut=NULL;
+  wave_station=station;
+  wave_user=user;
+  wave_peaks=NULL;
 }
 
 
 RDWavePainter::~RDWavePainter()
 {
-  RDWaveFile::closeWave();
+  if(wave_peaks!=NULL) {
+    delete wave_peaks;
+  }
 }
 
 
-void RDWavePainter::nameWave(QString file_name)
+void RDWavePainter::nameWave(RDCut *cut)
 {
-  wave_name=file_name;
-  RDWaveFile::nameWave(file_name);
+  wave_cut=cut;
+  LoadWave();
 }
 
 
-bool RDWavePainter::begin(const QPaintDevice *pd,const QString &wavname)
+bool RDWavePainter::begin(const QPaintDevice *pd,RDCut *cut)
 {
-  RDWaveFile::nameWave(wavname);
-  RDWaveFile::openWave();
+  wave_cut=cut;
+  LoadWave();
   return QPainter::begin(pd);
 }
 
@@ -69,13 +80,6 @@ bool RDWavePainter::begin(const QPaintDevice *pd)
 }
 
 
-bool RDWavePainter::end()
-{
- // RDWaveFile::closeWave();
-  return QPainter::end();
-}
-
-
 void RDWavePainter::drawWaveBySamples(int x,int w,int startsamp,int endsamp,
 				      int gain,Channel channel,
 				      const QColor &color,
@@ -87,7 +91,7 @@ void RDWavePainter::drawWaveBySamples(int x,int w,int startsamp,int endsamp,
   int endclipblock=-1;
 
 
-  if((startblock>(int)energySize())||(energySize()==0)) {
+  if((startblock>(int)wave_peaks->energySize())||(wave_peaks->energySize()==0)) {
     return;
   }
   if(startclip>=0) {
@@ -106,7 +110,7 @@ void RDWavePainter::drawWaveBySamples(int x,int w,int startsamp,int endsamp,
   switch(channel) {
       case RDWavePainter::Left:
       case RDWavePainter::Right:
-	if(getChannels()==1) {
+	if(wave_channels==1) {
 	  effective_channel=RDWavePainter::Mono;
 	}
 	break;
@@ -126,14 +130,14 @@ void RDWavePainter::drawWaveBySamples(int x,int w,int startsamp,int endsamp,
       case RDWavePainter::Left:
 	time_scale=(double)(endblock-startblock)/(double)w;
 	gain_scale=(double)(pix->height()/65536.0)*
-	  pow10((double)gain/2000.0);
+	  pow(10.0,(double)gain/2000.0);
 	for(int i=0;i<w;i++) {
 	  if(((dx=(2*((int)(time_scale*(double)i)+startblock)))<
-	     (int)energySize())&&
+	     (int)wave_peaks->energySize())&&
 	     ((startclipblock<0)||(dx>(startclipblock*2)))&&
 	     ((endclipblock<0)||(dx<(endclipblock*2)))) {
 	    array.setPoint(i+1,i+1,
-			   center+(int)(gain_scale*(double)energy(dx)));
+			   center+(int)(gain_scale*(double)wave_peaks->energy(dx)));
 	  }
 	  else {
 	    array.setPoint(i+1,i+1,center);
@@ -144,14 +148,14 @@ void RDWavePainter::drawWaveBySamples(int x,int w,int startsamp,int endsamp,
       case RDWavePainter::Right:
 	time_scale=(double)(endblock-startblock)/(double)w;
 	gain_scale=(double)(pix->height()/65536.0)*
-	  pow10((double)gain/2000.0);
+	  pow(10.0,(double)gain/2000.0);
 	for(int i=0;i<w;i++) {
 	  if(((dx=(1+2*((int)(time_scale*(double)i)+startblock)))<
-	     (int)energySize())&&
+	     (int)wave_peaks->energySize())&&
 	     ((startclipblock<0)||(dx>(startclipblock*2)))&&
 	     ((endclipblock<0)||(dx<(endclipblock*2)))) {
 	    array.setPoint(i+1,i+1,
-			   center+(int)(gain_scale*(double)energy(dx)));
+			   center+(int)(gain_scale*(double)wave_peaks->energy(dx)));
 	  }
 	  else {
 	    array.setPoint(i+1,i+1,center);
@@ -160,18 +164,18 @@ void RDWavePainter::drawWaveBySamples(int x,int w,int startsamp,int endsamp,
 	break;
 
       case RDWavePainter::Mono:
-	switch(getChannels()) {
+	switch(wave_channels) {
 	    case 1:
 	      time_scale=(double)(endblock-startblock)/(double)w;
 	      gain_scale=(double)(pix->height()/65536.0)*
-		pow10((double)gain/2000.0);
+		pow(10.0,(double)gain/2000.0);
 	      for(int i=0;i<w;i++) {
 		if(((dx=((int)(time_scale*(double)i)+startblock))<
-		   (int)energySize())&&
+		   (int)wave_peaks->energySize())&&
 		   ((startclipblock<0)||(dx>startclipblock))&&
 		   ((endclipblock<0)||(dx<endclipblock))) {
 		  array.setPoint(i+1,i+1,
-				 center+(int)(gain_scale*(double)energy(dx)));
+				 center+(int)(gain_scale*(double)wave_peaks->energy(dx)));
 		}
 		else {
 		  array.setPoint(i+1,i+1,center);
@@ -182,16 +186,16 @@ void RDWavePainter::drawWaveBySamples(int x,int w,int startsamp,int endsamp,
 	    case 2:
 	      time_scale=(double)(endblock-startblock)/(double)w;
 	      gain_scale=(double)(pix->height()/65536.0)*
-		pow10((double)gain/2000.0);
+		pow(10.0,(double)gain/2000.0);
 	      for(int i=0;i<w;i++) {
 		if(((dx=(2*((int)(time_scale*(double)i)+startblock)))<
-		   (int)energySize())&&
+		   (int)wave_peaks->energySize())&&
 		   ((startclipblock<0)||(dx>(startclipblock*2)))&&
 		   ((endclipblock<0)||(dx<(endclipblock*2)))) {
 		  array.setPoint(i+1,i+1,
 				 center+(int)(gain_scale*
-					      ((double)energy(dx)+
-					       (double)energy(dx+1))/2.0));
+					      ((double)wave_peaks->energy(dx)+
+					       (double)wave_peaks->energy(dx+1))/2.0));
 		}
 		else {
 		  array.setPoint(i+1,i+1,center);
@@ -216,9 +220,34 @@ void RDWavePainter::drawWaveByMsecs(int x,int w,int startmsecs,int endmsecs,
 				    int startclip,int endclip)
 {
   drawWaveBySamples(x,w,
-	     (unsigned)((double)startmsecs*(double)getSamplesPerSec()/1000.0),
-	     (unsigned)((double)endmsecs*(double)getSamplesPerSec()/1000.0),
+	     (unsigned)((double)startmsecs*(double)wave_sample_rate/1000.0),
+	     (unsigned)((double)endmsecs*(double)wave_sample_rate/1000.0),
 	     gain,channel,color,
-	     (int)((double)startclip*(double)getSamplesPerSec()/1000.0),
-	     (int)((double)endclip*(double)getSamplesPerSec()/1000.0));
+	     (int)((double)startclip*(double)wave_sample_rate/1000.0),
+	     (int)((double)endclip*(double)wave_sample_rate/1000.0));
+}
+
+
+void RDWavePainter::LoadWave()
+{
+  RDPeaksExport::ErrorCode peaks_err;
+
+  wave_sample_rate=wave_cut->sampleRate();
+  wave_channels=wave_cut->channels();
+  if(wave_peaks!=NULL) {
+    delete wave_peaks;
+  }
+  wave_peaks=new RDPeaksExport(wave_station);
+  wave_peaks->setCartNumber(wave_cut->cartNumber());
+  wave_peaks->setCutNumber(wave_cut->cutNumber());
+  if((peaks_err=wave_peaks->runExport(wave_user->name(),
+		  wave_user->password()))!=RDPeaksExport::ErrorOk) {
+    /*
+      QMessageBox::warning(NULL,QT_TR_NOOP("Rivendell Web Service"),
+		  QT_TR_NOOP("Unable to download peak data, error was:\n\"")+
+			   RDPeaksExport::errorText(peaks_err)+"\".");
+    return;
+    */
+  }
+
 }
