@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_dropbox.cpp,v 1.8.2.1 2008-11-29 15:48:10 fredg Exp $
+//      $Id: edit_dropbox.cpp,v 1.11 2010/07/29 19:32:34 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -295,6 +295,44 @@ EditDropbox::EditDropbox(int id,QWidget *parent,const char *name)
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
+  //
+  // Create Dates
+  //
+  box_create_dates_box=new QCheckBox(this,"box_create_dates_box");
+  box_create_dates_box->setGeometry(90,326,15,15);
+  label=new QLabel(box_create_dates_box,tr("Create Dates when no Dates Exist"),
+                   this,"box_create_dates_label");
+  label->setGeometry(110,324,sizeHint().width()-40,20);
+  label->setFont(font);
+  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  box_create_startdate_offset_spin=
+    new QSpinBox(this,"box_create_startdate_offset_spin");
+  box_create_startdate_offset_spin->setGeometry(300,350,50,20);
+  box_create_startdate_offset_spin->setRange(-180,180);
+  box_create_startdate_label= 
+     new QLabel(box_create_startdate_offset_spin,tr("Create start date offset:"),this,"box_create_startdate_label");
+  box_create_startdate_label->setGeometry(120,350,160,20);
+  box_create_startdate_label->setFont(font);
+  box_create_startdate_label->setAlignment(AlignVCenter|AlignRight);
+  box_create_startdate_unit= new QLabel(box_create_startdate_offset_spin,("days"),this,"box_create_start_days_unit");
+  box_create_startdate_unit->setGeometry(360,352,60,20);
+  box_create_startdate_unit->setAlignment(AlignVCenter|AlignLeft);
+  box_create_enddate_offset_spin=
+    new QSpinBox(this,"box_create_enddate_offset_spin");
+  box_create_enddate_offset_spin->setGeometry(300,380,50,20);
+  box_create_enddate_offset_spin->setRange(-180,180);
+  box_create_enddate_label= 
+     new QLabel(box_create_enddate_offset_spin,tr("Create end date offset:"),this,"box_create_enddate_label");
+  box_create_enddate_label->setGeometry(120,380,160,20);
+  box_create_enddate_label->setFont(font);
+  box_create_enddate_label->setAlignment(AlignVCenter|AlignRight);
+  box_create_enddate_unit= new QLabel(box_create_enddate_offset_spin,("days"),this,"box_create_end_days_unit");
+  box_create_enddate_unit->setGeometry(360,380,60,20);
+  box_create_enddate_unit->setAlignment(AlignVCenter|AlignLeft);
+  connect(box_create_dates_box,SIGNAL(toggled(bool)),
+          this,SLOT(createDatesToggledData(bool)));
+
+
   //
   //  Ok Button
   //
@@ -346,16 +384,19 @@ EditDropbox::EditDropbox(int id,QWidget *parent,const char *name)
   box_fix_broken_formats_box->setChecked(box_dropbox->fixBrokenFormats());
   box_startoffset_spin->setValue(box_dropbox->startdateOffset());
   box_endoffset_spin->setValue(box_dropbox->enddateOffset());
-
+  box_create_dates_box->setChecked(box_dropbox->createDates());
+  box_create_startdate_offset_spin->setValue(box_dropbox->createStartdateOffset());
+  box_create_enddate_offset_spin->setValue(box_dropbox->createEnddateOffset());
   toCartChangedData(box_to_cart_edit->text());
   normalizationToggledData(box_normalization_box->isChecked());
   autotrimToggledData(box_autotrim_box->isChecked());
+  createDatesToggledData(box_create_dates_box->isChecked());
 }
 
 
 QSize EditDropbox::sizeHint() const
 {
-  return QSize(450,400);
+  return QSize(450,500);
 } 
 
 
@@ -417,9 +458,38 @@ void EditDropbox::autotrimToggledData(bool state)
   box_autotrim_level_unit->setEnabled(state);
 }
 
+void EditDropbox::createDatesToggledData(bool state)
+{
+  box_create_startdate_offset_spin->setEnabled(state);
+  box_create_startdate_label->setEnabled(state);
+  box_create_startdate_unit->setEnabled(state);
+  box_create_enddate_offset_spin->setEnabled(state);
+  box_create_enddate_label->setEnabled(state);
+  box_create_enddate_unit->setEnabled(state);
+  if (!state) {
+    box_create_startdate_offset_spin->setValue(0);
+    box_create_enddate_offset_spin->setValue(0);
+  }
+}
+
 
 void EditDropbox::okData()
 {
+
+  //  Validate End Date Offsets
+  //
+  if (box_create_startdate_offset_spin->value() > box_create_enddate_offset_spin->value()) {
+     QMessageBox::warning(this,tr("Invalid Offsets"),
+           tr("The Create EndDate Offset is less than the Create Start Date Offset!"));
+     return;
+  }
+
+  if (box_startoffset_spin->value() > box_endoffset_spin->value()) {
+     QMessageBox::warning(this,tr("Invalid Offsets"),
+           tr("The EndDate Offset is less than the Start Date Offset!"));
+     return;
+  }
+
   box_dropbox->setGroupName(box_group_name_box->currentText());
   box_dropbox->setPath(box_path_edit->text());
   if(box_to_cart_edit->text().isEmpty()) {
@@ -451,7 +521,9 @@ void EditDropbox::okData()
   box_dropbox->setFixBrokenFormats(box_fix_broken_formats_box->isChecked());
   box_dropbox->setStartdateOffset(box_startoffset_spin->value());
   box_dropbox->setEnddateOffset(box_endoffset_spin->value());
-
+  box_dropbox->setCreateDates(box_create_dates_box->isChecked());
+  box_dropbox->setCreateStartdateOffset(box_create_startdate_offset_spin->value());
+  box_dropbox->setCreateEnddateOffset(box_create_enddate_offset_spin->value());
   done(0);
 }
 
