@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_matrix.h,v 1.13 2008/09/30 18:19:41 fredg Exp $
+//      $Id: edit_matrix.h,v 1.17 2011/05/07 00:32:29 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -56,8 +56,13 @@ class EditMatrix : public QDialog
   void livewireButtonData();
   void vguestRelaysButtonData();
   void vguestDisplaysButtonData();
+  void sasResourcesButtonData();
   void gpisChangedData(int value);
   void gposChangedData(int value);
+  void startCartData();
+  void stopCartData();
+  void startCart2Data();
+  void stopCart2Data();
   void okData();
   void cancelData();
 
@@ -90,6 +95,18 @@ class EditMatrix : public QDialog
   QLineEdit *edit_username2_edit;
   QLabel *edit_password2_label;
   QLineEdit *edit_password2_edit;
+  QLabel *edit_start_cart_label;
+  QLineEdit *edit_start_cart_edit;
+  QPushButton *edit_start_cart_button;
+  QLabel *edit_start_cart2_label;
+  QLineEdit *edit_start_cart2_edit;
+  QPushButton *edit_start_cart2_button;
+  QLabel *edit_stop_cart_label;
+  QLineEdit *edit_stop_cart_edit;
+  QPushButton *edit_stop_cart_button;
+  QLabel *edit_stop_cart2_label;
+  QLineEdit *edit_stop_cart2_edit;
+  QPushButton *edit_stop_cart2_button;
   QLabel *edit_port_label;
   QComboBox *edit_port_box;
   QLabel *edit_port2_label;
@@ -106,6 +123,7 @@ class EditMatrix : public QDialog
   QPushButton *edit_livewire_button;
   QPushButton *edit_vguestrelays_button;
   QPushButton *edit_vguestdisplays_button;
+  QPushButton *edit_sasresources_button;
   QLabel *edit_device_label;
   QLineEdit *edit_device_edit;
   QLabel *edit_gpis_label;
@@ -116,6 +134,7 @@ class EditMatrix : public QDialog
   QSpinBox *edit_card_box;
   QLabel *edit_displays_label;
   QSpinBox *edit_displays_box;
+  
 };
 
 
