@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_matrices.cpp,v 1.25.2.1.2.2 2010/05/08 23:01:57 cvs Exp $
+//      $Id: list_matrices.cpp,v 1.28 2011/05/23 21:53:22 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -287,6 +287,12 @@ void ListMatrices::DeleteMatrix(int matrix)
 			matrix);
   q=new RDSqlQuery(sql);
   delete q;
+  sql=QString().sprintf("delete from VGUEST_RESOURCES where \
+                         STATION_NAME=\"%s\" && MATRIX_NUM=%d",
+			(const char *)list_station,
+			matrix);
+  q=new RDSqlQuery(sql);
+  delete q;
 }
 
 
