@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.h,v 1.79.2.3 2008-12-02 20:35:24 fredg Exp $
+//      $Id: rdairplay.h,v 1.88 2010/10/21 18:26:10 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -36,6 +36,7 @@
 #include <qsocketdevice.h>
 #include <qpixmap.h>
 #include <qsplashscreen.h>
+#include <qfontmetrics.h>
 
 #include <rdpushbutton.h>
 #include <rdstereometer.h>
@@ -60,6 +61,8 @@
 #include <button_log.h>
 #include <colors.h>
 #include <rdsound_panel.h>
+#include <rdhotkeylist.h>
+#include <rdhotkeys.h>
 
 //
 // Debug Settings
@@ -78,6 +81,7 @@
 #define AIR_PANEL_BUTTON_ROWS 5
 #define AIR_PANEL_BUTTON_COLUMNS 5
 #define AIR_TOTAL_PORTS 3
+#define AIR_MESSAGE_FONT_QUANTITY 8
 #define METER_INTERVAL 20
 #define MASTER_TIMER_INTERVAL 100
 #define MESSAGE_WIDGET_WIDTH 410
@@ -185,6 +189,11 @@ class MainWidget : public QWidget
   QSocketDevice *air_nownext_socket;
   std::vector<RLMHost *> air_plugin_hosts;
   QSplashScreen *air_splash_screen;
+  int  keystrokecount;
+  bool AltKeyHit ;
+  bool CtrlKeyHit;
+  QFont air_message_fonts[AIR_MESSAGE_FONT_QUANTITY];
+  QFontMetrics *air_message_metrics[AIR_MESSAGE_FONT_QUANTITY];
 };
 
 
