@@ -2,9 +2,9 @@
 //
 // The Library Utility for Rivendell.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary.cpp,v 1.106.2.5 2009/11/25 17:19:24 cvs Exp $
+//      $Id: rdlibrary.cpp,v 1.113 2010/10/11 19:45:35 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,6 +38,7 @@
 #include <qlistview.h>
 #include <qprogressdialog.h>
 #include <qtooltip.h>
+#include <curl/curl.h>
 
 #include <rd.h>
 #include <rddb.h>
@@ -76,6 +77,7 @@ RDCut *cut_clipboard=NULL;
 RDConfig *lib_config;
 RDUser *lib_user;
 bool audio_changed;
+RDSystem *lib_system=NULL;
 
 //
 // Prototypes
@@ -92,24 +94,8 @@ void SigHandler(int signo);
 
 
 MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QDialog(parent,name)
+  :QWidget(parent,name)
 {
-  //
-  // Ensure We're the Only Instance Running
-  //
-  lib_lock=
-    new RDInstanceLock(QString().sprintf("%s/.rdlibrarylock",
-					(const char *)RDHomeDir()));
-  if(!lib_lock->lock()) {
-    fprintf(stderr,"rdlibrary: multiple instances not allowd\n");
-    exit(1);
-  }
-
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-
   //
   // Read Command Options
   //
@@ -122,6 +108,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   setMinimumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
 
+  //
+  // Initialize LibCurl
+  //
+  curl_global_init(CURL_GLOBAL_ALL);
+
   //
   // Generate Fonts
   //
@@ -142,11 +133,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   lib_rivendell_map=new QPixmap(rivendell_xpm);
   setIcon(*lib_rivendell_map);
 
-  //
-  // Text Validator
-  //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
-
   //
   // Progress Dialog
   //
@@ -176,12 +162,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   SetCaption("");
   lib_import_path=RDGetHomeDir();
 
-  //
-  // CAE Connection
-  //
-  rdcae=new RDCae(parent,name);
-  rdcae->connectHost("localhost",CAED_TCP_PORT,lib_config->password());
-
   //
   // Open Database
   //
@@ -206,6 +186,13 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   connect(rdripc,SIGNAL(userChanged()),this,SLOT(userData()));
   rdripc->connectHost("localhost",RIPCD_TCP_PORT,lib_config->password());
   cut_clipboard=NULL;
+  lib_system=new RDSystem();
+
+  //
+  // CAE Connection
+  //
+  rdcae=new RDCae(rdstation_conf,lib_config,parent,name);
+  rdcae->connectHost();
 
   //
   // Load Audio Assignments
@@ -222,20 +209,20 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   lib_filter_edit=new QLineEdit(this,"filter_edit");
   lib_filter_edit->setFont(default_font);
-  lib_filter_edit->setValidator(validator);
   lib_filter_label=new QLabel(lib_filter_edit,tr("Filter:"),
 			      this,"filter_label");
   lib_filter_label->setFont(button_font);
   lib_filter_label->setAlignment(AlignVCenter|AlignRight);
   connect(lib_filter_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(filterChangedData(const QString &)));
+  connect(lib_filter_edit,SIGNAL(returnPressed()),
+	  this,SLOT(searchClickedData()));
 
   //
   // Filter Search Button
   //
   lib_search_button=new QPushButton(tr("&Search"),this,"search_button");
   lib_search_button->setFont(button_font);
-  lib_search_button->setDefault(true);
   connect(lib_search_button,SIGNAL(clicked()),this,SLOT(searchClickedData()));
   switch(lib_filter_mode) {
     case RDStation::FilterSynchronous:
@@ -312,6 +299,22 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   lib_shownotes_label->setFont(button_font);
   lib_shownotes_label->setAlignment(AlignVCenter|AlignLeft);
 
+  //
+  // Show Matches Checkbox
+  //
+  lib_showmatches_box=new QCheckBox(this,"lib_showmatches_box");
+  lib_showmatches_box->setChecked(true);
+  lib_showmatches_box->setChecked(true);
+  lib_showmatches_label=
+    new QLabel(lib_showmatches_box,tr("Show Only First ")+
+	       QString().sprintf("%d",RD_LIMITED_CART_SEARCH_QUANTITY)+
+				 tr(" Matches"),
+	       this,"lib_showmatches_label");
+  lib_showmatches_label->setFont(button_font);
+  lib_showmatches_label->setAlignment(AlignVCenter|AlignLeft);
+  connect(lib_showmatches_box,SIGNAL(stateChanged(int)),
+	  this,SLOT(macroChangedData(int)));
+
   //
   // Cart List
   //
@@ -405,7 +408,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Disk Gauge
   //
-  disk_gauge=new DiskGauge(rdlibrary_conf->defaultSampleRate(),
+  disk_gauge=new DiskGauge(lib_system->sampleRate(),
 			   rdlibrary_conf->defaultChannels(),
 			   this,"disk_gauge");
 
@@ -556,7 +559,8 @@ void MainWidget::addData()
   QString cart_title;
   
   RDAddCart *add_cart=new RDAddCart(&lib_default_group,&cart_type,&cart_title,
-				    lib_user->name(),this,"add_cart");
+				    lib_user->name(),lib_system,
+				    this,"add_cart");
   if((cart_num=add_cart->exec())<0) {
     delete add_cart;
     return;
@@ -573,7 +577,7 @@ void MainWidget::addData()
   EditCart *cart=new EditCart(cart_num,&lib_import_path,true,this);
   if(cart->exec() <0) {
     RDCart *rdcart=new RDCart(cart_num);
-    rdcart->remove();
+    rdcart->remove(rdstation_conf,lib_user);
     delete rdcart;
   } 
   else {
@@ -717,21 +721,24 @@ Do you still want to delete it?"),item->text(1).toUInt());
       cut_clipboard=NULL;
     }
   }
-    if(del_flag && item->text(17).isEmpty()) {
-  RDCart *rdcart=new RDCart(item->text(1).toUInt());
-  rdcart->remove();
-  delete rdcart;
-  delete item;
-      } 
-    else {
-      ++(*it);
-      } 
+  if(del_flag && item->text(17).isEmpty()) {
+    RDCart *rdcart=new RDCart(item->text(1).toUInt());
+    if(!rdcart->remove(rdstation_conf,lib_user)) {
+      QMessageBox::warning(this,tr("RDLibrary"),tr("Unable to delete audio!"));
+      return;
+    }
+    delete rdcart;
+    delete item;
+  } 
+  else {
+    ++(*it);
+  } 
     }
     else {
       ++(*it);
-     } 
-   }
-   delete it;
+    } 
+  }
+  delete it;
 }
 
 
@@ -833,7 +840,6 @@ void MainWidget::macroChangedData(int state)
 void MainWidget::quitMainWidget()
 {
   SaveGeometry();
-  lib_lock->unlock();
   exit(0);
 }
 
@@ -868,22 +874,20 @@ void MainWidget::resizeEvent(QResizeEvent *e)
   lib_showmacro_label->setGeometry(250,65,130,20);
   lib_shownotes_box->setGeometry(390,67,15,15);
   lib_shownotes_label->setGeometry(410,65,130,20);
+  lib_showmatches_box->setGeometry(550,67,15,15);
+  lib_showmatches_label->setGeometry(570,65,200,20);
   lib_cart_list->
     setGeometry(10,90,e->size().width()-20,e->size().height()-155);
   lib_add_button->setGeometry(10,e->size().height()-60,80,50);
   lib_edit_button->setGeometry(100,e->size().height()-60,80,50);
   lib_delete_button->setGeometry(190,e->size().height()-60,80,50);
-  disk_gauge->setGeometry(290,e->size().height()-45,
-			  disk_gauge->sizeHint().width(),
+  disk_gauge->setGeometry(285,e->size().height()-45,
+			  e->size().width()-585,
 			  disk_gauge->sizeHint().height());
-  lib_rip_button->setGeometry(240+disk_gauge->sizeHint().width()+
-			      (e->size().width()-90-
-			       (280+disk_gauge->sizeHint().width()))/2-45,
-			      e->size().height()-60,80,50);
-  lib_reports_button->setGeometry(340+disk_gauge->sizeHint().width()+
-				  (e->size().width()-90-
-				   (280+disk_gauge->sizeHint().width()))/2-45,
-				  e->size().height()-60,80,50);
+  lib_rip_button->
+    setGeometry(e->size().width()-290,e->size().height()-60,80,50);
+  lib_reports_button->
+    setGeometry(e->size().width()-200,e->size().height()-60,80,50);
   lib_close_button->setGeometry(e->size().width()-90,e->size().height()-60,
 				80,50);
 }
@@ -940,6 +944,9 @@ void MainWidget::RefreshList()
     }  
   
   sql+=" order by CART.NUMBER";
+  if(lib_showmatches_box->isChecked()) {
+    sql+=QString().sprintf(" limit %d",RD_LIMITED_CART_SEARCH_QUANTITY);
+  }
   q=new RDSqlQuery(sql);
   int step=0;
   int count=0;
@@ -972,22 +979,22 @@ void MainWidget::RefreshList()
       }
       l=new RDListViewItem(lib_cart_list);
       switch((RDCart::Type)q->value(10).toUInt()) {
-	  case RDCart::Audio:
-	    if(q->value(17).isNull()) {
-	      l->setPixmap(0,*lib_playout_map);
-	    }
-	    else {
-	      l->setPixmap(0,*lib_track_cart_map);
-	    }
-	    break;
-	    
-	  case RDCart::Macro:
-	    l->setPixmap(0,*lib_macro_map);
-	    l->setBackgroundColor(backgroundColor());
-	    break;
-	    
-	  default:
-	    break;
+      case RDCart::Audio:
+	if(q->value(17).isNull()) {
+	  l->setPixmap(0,*lib_playout_map);
+	}
+	else {
+	  l->setPixmap(0,*lib_track_cart_map);
+	}
+	break;
+	
+      case RDCart::Macro:
+	l->setPixmap(0,*lib_macro_map);
+	l->setBackgroundColor(backgroundColor());
+	break;
+	
+      case RDCart::All:
+	break;
       }
       l->setText(1,QString().sprintf("%06d",q->value(0).toUInt()));
       l->setText(2,q->value(7).toString());
@@ -1123,7 +1130,7 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 	  item->setPixmap(0,*lib_macro_map);
 	  break;
 
-	default:
+    case RDCart::All:
 	  break;
     }
     item->setText(2,q->value(6).toString());
@@ -1241,10 +1248,10 @@ QString MainWidget::GetTypeFilter()
 
   if(lib_showaudio_box->isChecked()) {
     if(lib_showmacro_box->isChecked()) {
-      type_filter="((TYPE=1)||(TYPE=2))";
+      type_filter="((TYPE=1)||(TYPE=2)||(TYPE=3))";
     }
     else {
-      type_filter="(TYPE=1)";
+      type_filter="((TYPE=1)||(TYPE=3))";
     }
   }
   else {
@@ -1295,6 +1302,13 @@ void MainWidget::SaveGeometry()
   else {
     fprintf(file,"No\n");
   }
+  fprintf(file,"LimitMatches=");
+  if(lib_showmatches_box->isChecked()) {
+    fprintf(file,"Yes\n");
+  }
+  else {
+    fprintf(file,"No\n");
+  }
 
   fclose(file);
 }
