@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: record_cut.cpp,v 1.86.2.1 2010/01/20 22:22:50 cvs Exp $
+//      $Id: record_cut.cpp,v 1.90 2010/09/16 19:52:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -92,14 +92,14 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   connect(rdcae,SIGNAL(playStopped(int)),this,SLOT(playStoppedData(int)));
   connect(rdcae,SIGNAL(recordLoaded(int,int)),
 	  this,SLOT(recordLoadedData(int,int)));
-  connect(rdcae,SIGNAL(recordUnloaded(int,int)),
-	  this,SLOT(recordUnloadedData(int,int)));
+  connect(rdcae,SIGNAL(recordUnloaded(int,int,unsigned)),
+	  this,SLOT(recordUnloadedData(int,int,unsigned)));
   connect(rdcae,SIGNAL(recording(int,int)),this,SLOT(recordedData(int,int)));
   connect(rdcae,SIGNAL(recordStopped(int,int)),
 	  this,SLOT(recordStoppedData(int,int)));
   connect(rdcae,SIGNAL(inputStatusChanged(int,int,bool)),
 	  this,SLOT(aesAlarmData(int,int,bool)));
-  rdcae->connectHost("localhost",CAED_TCP_PORT,lib_config->password());
+  //rdcae->connectHost("localhost",CAED_TCP_PORT,lib_config->password());
 
   //
   // Audio Parameters
@@ -150,16 +150,28 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   cut_outcue_label->setFont(font);
   cut_outcue_label->setAlignment(AlignLeft|ShowPrefix);
 
+  //
+  // Cut ISCI Code
+  //
+  cut_isci_edit=new QLineEdit(this,"cut_isci_edit");
+  cut_isci_edit->setGeometry(10,120,355,19);
+  cut_isci_edit->setMaxLength(32);
+  QLabel *cut_isci_label=new QLabel(cut_isci_edit,tr("&ISCI Code"),this,
+				       "cut_isci_label");
+  cut_isci_label->setGeometry(15,101,120,19);
+  cut_isci_label->setFont(font);
+  cut_isci_label->setAlignment(AlignLeft|ShowPrefix);
+
   //
   // Cut Origin
   //
   cut_origin_edit=new QLineEdit(this,"cut_origin_edit");
-  cut_origin_edit->setGeometry(10,120,190,19);
+  cut_origin_edit->setGeometry(10,165,190,19);
   cut_origin_edit->setReadOnly(true);
   cut_origin_edit->setMaxLength(64);
   QLabel *cut_origin_label=new QLabel(cut_origin_edit,tr("Origin"),this,
 				       "cut_origin_label");
-  cut_origin_label->setGeometry(15,101,120,19);
+  cut_origin_label->setGeometry(15,146,120,19);
   cut_origin_label->setFont(font);
   cut_origin_label->setAlignment(AlignLeft|ShowPrefix);
 
@@ -167,11 +179,11 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Cut ISRC
   //
   cut_isrc_edit=new QLineEdit(this,"cut_isrc_edit");
-  cut_isrc_edit->setGeometry(220,120,145,19);
+  cut_isrc_edit->setGeometry(220,165,145,19);
   cut_isrc_edit->setMaxLength(64);
   QLabel *cut_isrc_label=new QLabel(cut_isrc_edit,tr("ISRC"),this,
 				       "cut_isrc_label");
-  cut_isrc_label->setGeometry(225,101,120,19);
+  cut_isrc_label->setGeometry(225,146,120,19);
   cut_isrc_label->setFont(font);
   cut_isrc_label->setAlignment(AlignLeft|ShowPrefix);
 
@@ -179,11 +191,11 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Cut Weight
   //
   cut_weight_box=new QSpinBox(this,"cut_weight_box");
-  cut_weight_box->setGeometry(10,165,61,19);
+  cut_weight_box->setGeometry(10,210,61,19);
   cut_weight_box->setRange(0,100);
   QLabel *cut_weight_label=new QLabel(cut_weight_box,tr("Weight"),this,
 				       "cut_weight_label");
-  cut_weight_label->setGeometry(10,146,61,19);
+  cut_weight_label->setGeometry(10,191,61,19);
   cut_weight_label->setFont(font);
   cut_weight_label->setAlignment(AlignHCenter|ShowPrefix);
 
@@ -191,12 +203,12 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Cut Play Date Time
   //
   cut_playdate_edit=new QLineEdit(this,"cut_playdate_edit");
-  cut_playdate_edit->setGeometry(100,165,150,19);
+  cut_playdate_edit->setGeometry(100,210,150,19);
   cut_playdate_edit->setReadOnly(true);
   cut_playdate_edit->setMaxLength(64);
   QLabel *cut_playdate_label=new QLabel(cut_playdate_edit,tr("Last Played"),
 					this,"cut_playdate_label");
-  cut_playdate_label->setGeometry(105,146,120,19);
+  cut_playdate_label->setGeometry(105,191,120,19);
   cut_playdate_label->setFont(font);
   cut_playdate_label->setAlignment(AlignLeft|ShowPrefix);
 
@@ -204,14 +216,14 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Cut Play Counter
   //
   cut_playcounter_edit=new QLineEdit(this,"cut_playcounter_edit");
-  cut_playcounter_edit->setGeometry(285,165,80,19);
+  cut_playcounter_edit->setGeometry(285,210,80,19);
   cut_playcounter_edit->setAlignment(AlignRight);
   cut_playcounter_edit->setReadOnly(true);
   cut_playcounter_edit->setMaxLength(64);
   QLabel *cut_playcounter_label=
     new QLabel(cut_playcounter_edit,tr("# of Plays"),
 	       this,"cut_playcounter_label");
-  cut_playcounter_label->setGeometry(290,146,120,19);
+  cut_playcounter_label->setGeometry(290,191,120,19);
   cut_playcounter_label->setFont(font);
   cut_playcounter_label->setAlignment(AlignLeft|ShowPrefix);
 
@@ -219,10 +231,10 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Evergreen Checkbox
   //
   rec_evergreen_box=new QCheckBox(this,"rec_evergreen_box");
-  rec_evergreen_box->setGeometry(10,200,15,15);
+  rec_evergreen_box->setGeometry(10,245,15,15);
   rec_evergreen_label=new QLabel(rec_evergreen_box,tr("Cut is EVERGREEN"),
 				 this,"rec_evergreen_label");
-  rec_evergreen_label->setGeometry(30,200,sizeHint().width()-40,15);
+  rec_evergreen_label->setGeometry(30,245,sizeHint().width()-40,15);
   rec_evergreen_label->setFont(font);
   rec_evergreen_label->setAlignment(AlignVCenter|AlignLeft);
   connect(rec_evergreen_box,SIGNAL(toggled(bool)),
@@ -233,7 +245,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   //
   cut_killdatetime_label=new QLabel(tr("Air Date/Time"),
 				    this,"cut_killdatetime_label");
-  cut_killdatetime_label->setGeometry(50,223,100,19);
+  cut_killdatetime_label->setGeometry(50,268,100,19);
   cut_killdatetime_label->setAlignment(Qt::AlignHCenter);
   cut_killdatetime_label->setFont(font);
   QButtonGroup *button_group=new QButtonGroup(this,"air_dates_group");
@@ -241,26 +253,26 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   connect(button_group,SIGNAL(clicked(int)),this,SLOT(airDateButtonData(int)));
   cut_startdatetime_enable_button=new QRadioButton(tr("Enabled"),this,
 					       "air_date_enabled_button");
-  cut_startdatetime_enable_button->setGeometry(40,245,100,20);
+  cut_startdatetime_enable_button->setGeometry(40,290,100,20);
   button_group->insert(cut_startdatetime_enable_button,true);
   cut_startdatetime_disable_button=new QRadioButton(tr("Disabled"),this,
 						"air_date_disabled_button");
-  cut_startdatetime_disable_button->setGeometry(40,265,100,20);
+  cut_startdatetime_disable_button->setGeometry(40,310,100,20);
   button_group->insert(cut_startdatetime_disable_button,false);
 
   cut_startdatetime_edit=new QDateTimeEdit(this,"cut_startdatetime_edit");
-  cut_startdatetime_edit->setGeometry(165,244,170,19);
+  cut_startdatetime_edit->setGeometry(165,289,170,19);
   cut_startdatetime_label=new QLabel(cut_startdatetime_edit,tr("&Start"),this,
 				       "cut_startdatetime_label");
-  cut_startdatetime_label->setGeometry(120,248,40,12);
+  cut_startdatetime_label->setGeometry(120,293,40,12);
   cut_startdatetime_label->setFont(small_font);
   cut_startdatetime_label->setAlignment(AlignRight|ShowPrefix);
 
   cut_enddatetime_edit=new QDateTimeEdit(this,"cut_enddatetime_edit");
-  cut_enddatetime_edit->setGeometry(165,264,170,19);
+  cut_enddatetime_edit->setGeometry(165,309,170,19);
   cut_enddatetime_label=new QLabel(cut_enddatetime_edit,tr("End"),this,
 				       "cut_enddatetime_label");
-  cut_enddatetime_label->setGeometry(120,268,40,12);
+  cut_enddatetime_label->setGeometry(120,313,40,12);
   cut_enddatetime_label->setFont(small_font);
   cut_enddatetime_label->setAlignment(AlignRight|ShowPrefix);
 
@@ -268,7 +280,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Cut Daypart
   //
   cut_daypart_label=new QLabel(tr("Daypart"),this);
-  cut_daypart_label->setGeometry(50,303,65,19);
+  cut_daypart_label->setGeometry(50,348,65,19);
   cut_daypart_label->setAlignment(Qt::AlignHCenter);
   cut_daypart_label->setFont(font);
   button_group=new QButtonGroup(this,"daypart_group");
@@ -276,26 +288,26 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   connect(button_group,SIGNAL(clicked(int)),this,SLOT(daypartButtonData(int)));
   cut_starttime_enable_button=new QRadioButton(tr("Enabled"),this,
 					       "daypart_enabled_button");
-  cut_starttime_enable_button->setGeometry(57,325,100,20);
+  cut_starttime_enable_button->setGeometry(57,370,100,20);
   button_group->insert(cut_starttime_enable_button,true);
   cut_starttime_disable_button=new QRadioButton(tr("Disabled"),this,
 				"daypart_disabled_button");
-  cut_starttime_disable_button->setGeometry(57,345,100,20);
+  cut_starttime_disable_button->setGeometry(57,390,100,20);
   button_group->insert(cut_starttime_disable_button,false);
 
   cut_starttime_edit=new RDTimeEdit(this,"cut_starttime_edit");
-  cut_starttime_edit->setGeometry(222,324,90,19);
+  cut_starttime_edit->setGeometry(222,369,90,19);
   cut_starttime_label=new QLabel(cut_starttime_edit,tr("&Start Time"),this,
 				       "cut_starttime_label");
-  cut_starttime_label->setGeometry(137,328,80,12);
+  cut_starttime_label->setGeometry(137,373,80,12);
   cut_starttime_label->setFont(small_font);
   cut_starttime_label->setAlignment(AlignRight|ShowPrefix);
 
   cut_endtime_edit=new RDTimeEdit(this,"cut_endtime_edit");
-  cut_endtime_edit->setGeometry(222,344,90,19);
+  cut_endtime_edit->setGeometry(222,389,90,19);
   cut_endtime_label=new QLabel(cut_endtime_edit,tr("End Time"),this,
 				       "cut_endtime_label");
-  cut_endtime_label->setGeometry(137,348,80,12);
+  cut_endtime_label->setGeometry(137,393,80,12);
   cut_endtime_label->setFont(small_font);
   cut_endtime_label->setAlignment(AlignRight|ShowPrefix);
 
@@ -303,72 +315,72 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Days of the Week
   //
   rec_dayofweek_label=new QLabel(tr("Day of the Week"),this);
-  rec_dayofweek_label->setGeometry(50,383,125,19);
+  rec_dayofweek_label->setGeometry(50,428,125,19);
   rec_dayofweek_label->setAlignment(Qt::AlignHCenter);
   rec_dayofweek_label->setFont(font);
   rec_weekpart_button[0]=new QCheckBox(this,"cut_weekpart_button[0]");
-  rec_weekpart_button[0]->setGeometry(40,402,15,15);
+  rec_weekpart_button[0]->setGeometry(40,447,15,15);
   rec_weekpart_label[0]=new QLabel(rec_weekpart_button[0],tr("Monday"),
 		   this,"rec_weekpart_label[0]");
-  rec_weekpart_label[0]->setGeometry(62,400,80,20);
+  rec_weekpart_label[0]->setGeometry(62,445,80,20);
   rec_weekpart_label[0]->setFont(day_font);
   rec_weekpart_label[0]->setAlignment(AlignVCenter|AlignLeft);
 
   rec_weekpart_button[1]=new QCheckBox(this,"cut_weekpart_button[1]");
-  rec_weekpart_button[1]->setGeometry(120,402,15,15);
+  rec_weekpart_button[1]->setGeometry(120,447,15,15);
   rec_weekpart_label[1]=new QLabel(rec_weekpart_button[1],tr("Tuesday"),
 		   this,"rec_weekpart_label[0]");
-  rec_weekpart_label[1]->setGeometry(142,400,80,20);
+  rec_weekpart_label[1]->setGeometry(142,445,80,20);
   rec_weekpart_label[1]->setFont(day_font);
   rec_weekpart_label[1]->setAlignment(AlignVCenter|AlignLeft);
 
   rec_weekpart_button[2]=new QCheckBox(this,"cut_weekpart_button[2]");
-  rec_weekpart_button[2]->setGeometry(200,402,15,15);
+  rec_weekpart_button[2]->setGeometry(200,447,15,15);
   rec_weekpart_label[2]=new QLabel(rec_weekpart_button[2],tr("Wednesday"),
 		   this,"rec_weekpart_label[0]");
-  rec_weekpart_label[2]->setGeometry(222,400,80,20);
+  rec_weekpart_label[2]->setGeometry(222,445,80,20);
   rec_weekpart_label[2]->setFont(day_font);
   rec_weekpart_label[2]->setAlignment(AlignVCenter|AlignLeft);
 
   rec_weekpart_button[3]=new QCheckBox(this,"cut_weekpart_button[3]");
-  rec_weekpart_button[3]->setGeometry(80,422,15,15);
+  rec_weekpart_button[3]->setGeometry(80,467,15,15);
   rec_weekpart_label[3]=new QLabel(rec_weekpart_button[3],tr("Thursday"),
 		   this,"rec_weekpart_label[3]");
-  rec_weekpart_label[3]->setGeometry(102,420,80,20);
+  rec_weekpart_label[3]->setGeometry(102,465,80,20);
   rec_weekpart_label[3]->setFont(day_font);
   rec_weekpart_label[3]->setAlignment(AlignVCenter|AlignLeft);
 
   rec_weekpart_button[4]=new QCheckBox(this,"cut_weekpart_button[4]");
-  rec_weekpart_button[4]->setGeometry(180,422,15,15);
+  rec_weekpart_button[4]->setGeometry(180,467,15,15);
   rec_weekpart_label[4]=new QLabel(rec_weekpart_button[4],tr("Friday"),
 		   this,"rec_weekpart_label[4]");
-  rec_weekpart_label[4]->setGeometry(202,420,80,20);
+  rec_weekpart_label[4]->setGeometry(202,465,80,20);
   rec_weekpart_label[4]->setFont(day_font);
   rec_weekpart_label[4]->setAlignment(AlignVCenter|AlignLeft);
 
   rec_weekpart_button[5]=new QCheckBox(this,"cut_weekpart_button[5]");
-  rec_weekpart_button[5]->setGeometry(80,442,15,15);
+  rec_weekpart_button[5]->setGeometry(80,487,15,15);
   rec_weekpart_label[5]=new QLabel(rec_weekpart_button[5],tr("Saturday"),
 		   this,"rec_weekpart_label[5]");
-  rec_weekpart_label[5]->setGeometry(102,440,80,20);
+  rec_weekpart_label[5]->setGeometry(102,485,80,20);
   rec_weekpart_label[5]->setFont(day_font);
   rec_weekpart_label[5]->setAlignment(AlignVCenter|AlignLeft);
 
   rec_weekpart_button[6]=new QCheckBox(this,"cut_weekpart_button[6]");
-  rec_weekpart_button[6]->setGeometry(180,440,15,15);
+  rec_weekpart_button[6]->setGeometry(180,485,15,15);
   rec_weekpart_label[6]=new QLabel(rec_weekpart_button[6],tr("Sunday"),
 		   this,"rec_weekpart_label[6]");
-  rec_weekpart_label[6]->setGeometry(202,440,80,20);
+  rec_weekpart_label[6]->setGeometry(202,485,80,20);
   rec_weekpart_label[6]->setFont(day_font);
   rec_weekpart_label[6]->setAlignment(AlignVCenter|AlignLeft);
 
   rec_set_button=new QPushButton(tr("Set All"),this,"rec_set_button");
-  rec_set_button->setGeometry(sizeHint().width()-80,396,55,30);
+  rec_set_button->setGeometry(sizeHint().width()-80,441,55,30);
   rec_set_button->setFont(small_font);
   connect(rec_set_button,SIGNAL(clicked()),this,SLOT(setAllData()));
 
   rec_clear_button=new QPushButton(tr("Clear All"),this,"rec_clear_button");
-  rec_clear_button->setGeometry(sizeHint().width()-80,431,55,30);
+  rec_clear_button->setGeometry(sizeHint().width()-80,476,55,30);
   rec_clear_button->setFont(small_font);
   connect(rec_clear_button,SIGNAL(clicked()),this,SLOT(clearAllData()));
 
@@ -376,7 +388,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Audio Meter
   //
   rec_meter=new RDStereoMeter(this,"rec_meter");
-  rec_meter->setGeometry(20,475,rec_meter->geometry().width(),
+  rec_meter->setGeometry(20,520,rec_meter->geometry().width(),
 			 rec_meter->geometry().height());
   rec_meter->setReference(0);
   rec_meter->setMode(RDSegMeter::Independent);
@@ -388,7 +400,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // AES Alarm
   //
   rec_aes_alarm_label=new QLabel(this,"rec_aes_alarm_label");
-  rec_aes_alarm_label->setGeometry(15,547,110,25);
+  rec_aes_alarm_label->setGeometry(15,592,110,25);
   rec_aes_alarm_label->setAlignment(AlignHCenter|AlignVCenter);
   rec_aes_alarm_label->setFont(large_font);
   rec_aes_alarm_label->setPalette(QColor(red));
@@ -401,7 +413,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   rec_timer=new QTimer(this,"rec_timer");
   connect(rec_timer,SIGNAL(timeout()),this,SLOT(recTimerData()));
   rec_timer_label=new QLabel(this,"rec_timer_label");
-  rec_timer_label->setGeometry(130,535,120,50);
+  rec_timer_label->setGeometry(130,580,120,50);
   rec_timer_label->setFont(timer_font);
   rec_timer_label->setAlignment(AlignLeft|AlignVCenter);
   rec_timer_label->setText(RDGetTimeLength(rec_length,true));
@@ -410,12 +422,12 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Channels
   //
   rec_channels_box=new QComboBox(this,"rec_channels_box");
-  rec_channels_box->setGeometry(20,590,60,35);
+  rec_channels_box->setGeometry(20,635,60,35);
   rec_channels_edit=new QLineEdit(this,"rec_channels_box");
-  rec_channels_edit->setGeometry(20,590,60,35);
+  rec_channels_edit->setGeometry(20,635,60,35);
   QLabel *rec_channels_box_label=new QLabel(rec_channels_box,tr("Channels"),
 					    this,"rec_channels_box_label");
-  rec_channels_box_label->setGeometry(10,571,80,16);
+  rec_channels_box_label->setGeometry(10,616,80,16);
   rec_channels_box_label->setAlignment(AlignHCenter);
   rec_channels_box_label->setFont(font);
   connect(rec_channels_box,SIGNAL(activated(int)),
@@ -426,7 +438,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   //
   rec_record_button=new RDTransportButton(RDTransportButton::Record,
 					this,"rec_record_button");
-  rec_record_button->setGeometry(100,575,80,50);
+  rec_record_button->setGeometry(100,620,80,50);
   rec_record_button->setDefault(true);
   connect(rec_record_button,SIGNAL(clicked()),this,SLOT(recordData()));
 
@@ -435,7 +447,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   //
   rec_play_button=new RDTransportButton(RDTransportButton::Play,
 					this,"rec_play_button");
-  rec_play_button->setGeometry(190,575,80,50);
+  rec_play_button->setGeometry(190,620,80,50);
   rec_play_button->setDefault(true);
   connect(rec_play_button,SIGNAL(clicked()),this,SLOT(playData()));
 
@@ -444,7 +456,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   //
   rec_stop_button=new RDTransportButton(RDTransportButton::Stop,
 					this,"rec_stop_button");
-  rec_stop_button->setGeometry(280,575,80,50);
+  rec_stop_button->setGeometry(280,620,80,50);
   rec_stop_button->setDefault(true);
   rec_stop_button->setState(RDTransportButton::On);
   rec_stop_button->setOnColor(QColor(red));
@@ -454,10 +466,10 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // Record Mode 
   //
   rec_mode_box=new QComboBox(this,"rec_mode_box");
-  rec_mode_box->setGeometry(10,650,100,35);
+  rec_mode_box->setGeometry(10,695,100,35);
   QLabel *rec_mode_box_label=new QLabel(rec_mode_box,tr("Record Mode"),this,
 					"rec_mode_box_label");
-  rec_mode_box_label->setGeometry(10,631,100,16);
+  rec_mode_box_label->setGeometry(10,676,100,16);
   rec_mode_box_label->setAlignment(AlignHCenter);
   rec_mode_box_label->setFont(font);
 
@@ -465,10 +477,10 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   // AutoTrim Mode 
   //
   rec_trim_box=new QComboBox(this,"rec_trim_box");
-  rec_trim_box->setGeometry(145,650,70,35);
+  rec_trim_box->setGeometry(145,695,70,35);
   QLabel *rec_trim_box_label=new QLabel(rec_trim_box,tr("AutoTrim"),this,
 					"rec_trim_box_label");
-  rec_trim_box_label->setGeometry(130,631,100,16);
+  rec_trim_box_label->setGeometry(130,676,100,16);
   rec_trim_box_label->setAlignment(AlignHCenter);
   rec_trim_box_label->setFont(font);
 
@@ -494,6 +506,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
     cut_origin_edit->setText(cut_origin_name+" - "+
 	       	     cut_origin_datetime.toString("M/d/yyyy hh:mm:ss"));
   }
+  cut_isci_edit->setText(rec_cut->isci());
   cut_isrc_edit->setText(rec_cut->isrc(RDCut::FormattedIsrc));
   cut_weight_box->setValue(rec_cut->weight());
   if(rec_cut->playCounter()>0) {
@@ -553,6 +566,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   //
   cut_description_edit->setReadOnly(!allow_modification);
   cut_outcue_edit->setReadOnly(!allow_modification);
+  cut_isci_edit->setReadOnly(!allow_modification);
   cut_starttime_edit->setReadOnly(!allow_modification);
   cut_endtime_edit->setReadOnly(!allow_modification);
   if(!allow_modification) {
@@ -596,8 +610,6 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   else {
     rec_channels_box->hide();
   }
-
-
 }
 
 
@@ -614,7 +626,7 @@ RecordCut::~RecordCut()
 
 QSize RecordCut::sizeHint() const
 {
-  return QSize(375,695);
+  return QSize(375,740);
 } 
 
 
@@ -723,7 +735,7 @@ void RecordCut::recordData()
 	  rec_format=RDCae::Pcm16;
 	  break;
     }
-    rec_samprate=rdlibrary_conf->defaultSampleRate();
+    rec_samprate=lib_system->sampleRate();
     rec_cut->setSampleRate(rec_samprate);
     rec_bitrate=rdlibrary_conf->defaultBitrate();
     rec_cut->setBitRate(rec_bitrate);
@@ -843,6 +855,7 @@ void RecordCut::playStoppedData(int handle)
 
 void RecordCut::recordStoppedData(int card,int stream)
 {
+  //printf("recordStoppedData()\n");
   rdcae->unloadRecord(rec_card_no[0],rec_port_no[0]);
   rec_timer->stop();
   rec_play_button->off();
@@ -854,13 +867,20 @@ void RecordCut::recordStoppedData(int card,int stream)
 }
 
 
-void RecordCut::recordUnloadedData(int card,int stream)
+void RecordCut::recordUnloadedData(int card,int stream,unsigned len)
 {
+  //printf("recordUnloadedData(%d,%d,%u)\n",card,stream,len);
   QString filename;
 
   rec_meter->setLeftSolidBar(-100000);
   rec_meter->setRightSolidBar(-100000);
-  rec_cut->checkInRecording(rdstation_conf->name());
+
+  RDSettings *s=new RDSettings();
+  s->setSampleRate(rec_samprate);
+  s->setBitRate(rec_bitrate);
+  s->setChannels(rec_channels);
+  s->setFormat((RDSettings::Format)rec_format);
+  rec_cut->checkInRecording(rdstation_conf->name(),s,len);
   if(rec_trim_box->currentItem()==0) {
     rec_cut->autoTrim(RDCut::AudioBoth,rdlibrary_conf->trimThreshold());
   }
@@ -974,6 +994,7 @@ void RecordCut::closeData()
   rec_cut->setDescription(cut_description_edit->text());
   rec_cut->setOutcue(cut_outcue_edit->text());
   rec_cut->setIsrc(isrc);
+  rec_cut->setIsci(cut_isci_edit->text());
   rec_cut->setWeight(cut_weight_box->value());
   rec_cut->setLength(rec_length);
   rec_cart=new RDCart(rec_cut->cartNumber());
@@ -1075,9 +1096,9 @@ void RecordCut::paintEvent(QPaintEvent *e)
   else {
     p->setPen(palette().color(QPalette::Active,QColorGroup::Foreground));
   }
-  p->drawRect(30,230,sizeHint().width()-60,60);
-  p->drawRect(37,310,sizeHint().width()-74,60);
-  p->drawRect(20,391,sizeHint().width()-40,75);
+  p->drawRect(30,275,sizeHint().width()-60,60);
+  p->drawRect(37,355,sizeHint().width()-74,60);
+  p->drawRect(20,436,sizeHint().width()-40,75);
   p->end();
 }
 
