@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: record_cut.h,v 1.30.2.1 2010/01/20 22:22:51 cvs Exp $
+//      $Id: record_cut.h,v 1.33 2010/09/16 19:52:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -67,7 +67,7 @@ class RecordCut : public QDialog
    void recordLoadedData(int,int);
    void recordedData(int,int);
    void recordStoppedData(int,int);
-   void recordUnloadedData(int,int);
+   void recordUnloadedData(int,int,unsigned);
    void playedData(int);
    void playStoppedData(int);
    void closeData();
@@ -92,6 +92,7 @@ class RecordCut : public QDialog
    QLineEdit *cut_outcue_edit;
    QLineEdit *cut_origin_edit;
    QLineEdit *cut_isrc_edit;
+   QLineEdit *cut_isci_edit;
    QSpinBox *cut_weight_box;
    QLineEdit *cut_playdate_edit;
    QLineEdit *cut_playcounter_edit;
