@@ -393,6 +393,10 @@ die für den gewählten Service ungültig sind!</translation>
         <source>Select</source>
         <translation>Auswählen</translation>
     </message>
+    <message>
+        <source>Unable to save log, audio deletion error!</source>
+        <translation>Kann Logdatei nicht speichern, Audiolöschfehler!</translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -490,11 +494,11 @@ Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>Duplicate Start Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Doppelte Startzeit</translation>
     </message>
     <message>
         <source>An event is already scheduled with this start time!</source>
-        <translation type="unfinished"></translation>
+        <translation>Es existiert bereits ein Event mit dieser Startzeit!</translation>
     </message>
 </context>
 <context>
@@ -825,5 +829,13 @@ Fortfahren?</translation>
         <source>TFN</source>
         <translation>TFN</translation>
     </message>
+    <message>
+        <source>RDLogEdit</source>
+        <translation>RDLogEdit</translation>
+    </message>
+    <message>
+        <source>Unable to delete log, audio deletion error!</source>
+        <translation>Kann Logdatei nicht löschen, Audiolöschfehler!</translation>
+    </message>
 </context>
 </TS>
