@@ -393,6 +393,10 @@ desactivados para el servicio actual!
         <source>Select</source>
         <translation>Seleccionar</translation>
     </message>
+    <message>
+        <source>Unable to save log, audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -825,5 +829,13 @@ Report</source>
         <translation>Reporte
 de PlayList</translation>
     </message>
+    <message>
+        <source>RDLogEdit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log, audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
