@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddbcheck.h,v 1.5 2008-06-24 22:17:49 fredg Exp $
+//      $Id: rddbcheck.h,v 1.9 2010/12/13 16:48:01 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,10 +29,12 @@
 #include <qobject.h>
 #include <qsqldatabase.h>
 
+#include <rduser.h>
 #include <rdconfig.h>
 #include <rdcmd_switch.cpp>
+#include <rdstation.h>
 
-#define RDDBCHECK_USAGE "[--yes|--no]\n\nCheck the Rivendell database and audio store for consistency\nand correctness.\n\n   --yes     Answer all questions with 'yes'\n\n   --no      Answer all questions with 'no'\n"
+#define RDDBCHECK_USAGE "[options]\n\nCheck the Rivendell database and audio store for consistency\nand correctness.\n\n--yes\n     Answer all questions with 'yes'\n\n--no\n     Answer all questions with 'no'\n\n--orphan-group=<group-name>\n     Move carts with missing/invalid GROUP information to the <group-name>\n     group.\n\n--dump-cuts-dir=<dir-name>\n     Move orphaned cut audio to the <dir-name> directory.\n"
 
 //
 // Global Variables
@@ -50,12 +52,22 @@ class MainObject : public QObject
   void CheckClocks();
   void CheckEvents();
   void CheckOrphanedTables();
+  void CheckCutCounts();
+  void CheckOrphanedCarts();
+  void CheckOrphanedCuts();
+  void CheckOrphanedAudio();
+  void ValidateAudioLengths();
+  void SetCutLength(const QString &cutname,int len);
   void CleanTables(const QString &ext,QSqlQuery *table_q,QSqlQuery *name_q);
   void CleanTables(const QString &ext,QSqlQuery *table_q);
   bool IsTableLinked(QSqlQuery *name_q,const QString &ext,const QString &table);
   bool UserResponse();
   bool check_yes;
   bool check_no;
+  QString orphan_group_name;
+  QString dump_cuts_dir;
+  RDStation *check_station;
+  RDUser *check_user;
 };
 
 
