@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdgpimon.cpp,v 1.10.2.1 2008/12/08 16:44:21 fredg Exp $
+//      $Id: rdgpimon.cpp,v 1.14 2011/05/27 21:28:25 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -48,11 +48,6 @@
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QWidget(parent,name)
 {
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-
   //
   // Read Command Options
   //
@@ -172,7 +167,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   for(int i=0;i<GPIMON_ROWS;i++) {
     for(int j=0;j<GPIMON_COLS;j++) {
       gpi_labels[i*GPIMON_COLS+j]=new GpiLabel(this);
-      gpi_labels[i*GPIMON_COLS+j]->setGeometry(10+64*j,40+70*i,
+      gpi_labels[i*GPIMON_COLS+j]->setGeometry(10+64*j,40+78*i,
 					       gpi_labels[i*GPIMON_COLS+j]->
 					       sizeHint().width(),
 					       gpi_labels[i*GPIMON_COLS+j]->
@@ -245,7 +240,7 @@ MainWidget::~MainWidget()
 
 QSize MainWidget::sizeHint() const
 {
-  return QSize(528,70*GPIMON_ROWS+110);
+  return QSize(528,78*GPIMON_ROWS+110);
 }
 
 
@@ -554,7 +549,7 @@ int main(int argc,char *argv[])
   a.installTranslator(&rdhpi);
 
   QTranslator tr(0);
-  tr.load(QString(PREFIX)+QString("/share/rivendell/rdutils_")+
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdgpimon_")+
 	     QTextCodec::locale(),".");
   a.installTranslator(&tr);
 
