@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport.cpp,v 1.23.2.6 2009/11/24 21:25:58 cvs Exp $
+//      $Id: rdimport.cpp,v 1.32 2011/04/05 12:03:55 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,6 +28,8 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <ctype.h>
+#include <sched.h>
+#include <errno.h>
 
 #include <qapplication.h>
 #include <qdir.h>
@@ -39,18 +41,18 @@
 #include <rdlibrary_conf.h>
 #include <rdescape_string.h>
 #include <rddbheartbeat.h>
-
+#include <rdaudioimport.h>
 
 volatile bool import_run=true;
 
 void SigHandler(int signo)
 {
   switch(signo) {
-      case SIGTERM:
-      case SIGINT:
-      case SIGHUP:
-	import_run=false;
-	break;
+  case SIGTERM:
+  case SIGINT:
+  case SIGHUP:
+    import_run=false;
+    break;
   }
 }
 
@@ -79,6 +81,9 @@ MainObject::MainObject(QObject *parent,const char *name)
   import_enddate_offset=0;
   import_fix_broken_formats=false;
   import_persistent_dropbox_id=-1;
+  import_create_dates=false;
+  import_create_startdate_offset=0;
+  import_create_enddate_offset=0;
 
   //
   // Read Command Options
@@ -172,6 +177,25 @@ MainObject::MainObject(QObject *parent,const char *name)
 	exit(256);
       }
     }
+    if(import_cmd->key(i)=="--create-startdate-offset") {
+      import_create_startdate_offset=import_cmd->value(i).toInt(&ok);
+      if(!ok) {
+	fprintf(stderr,"rdimport: invalid create-startddate-offset\n");
+	delete import_cmd;
+	exit(256);
+      }
+      import_create_dates=true;
+    }
+    if(import_cmd->key(i)=="--create-enddate-offset") {
+      import_create_enddate_offset=import_cmd->value(i).toInt(&ok);
+      if((!ok) || 
+         (import_create_startdate_offset > import_create_enddate_offset )) {
+	fprintf(stderr,"rdimport: invalid create-enddate-offset\n");
+	delete import_cmd;
+	exit(256);
+      }
+      import_create_dates=true;
+    }
   }
 
   //
@@ -200,6 +224,24 @@ MainObject::MainObject(QObject *parent,const char *name)
   }
   new RDDbHeartbeat(import_config->mysqlHeartbeatInterval(),this);
 
+  //
+  // RIPC Connection
+  //
+  import_ripc=new RDRipc(import_config->stationName());
+  connect(import_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
+  import_ripc->
+    connectHost("localhost",RIPCD_TCP_PORT,import_config->password());
+
+  //
+  // Station Configuration
+  //
+  import_station=new RDStation(import_config->stationName());
+
+  //
+  // User
+  //
+  import_user=NULL;
+
   //
   // Verify Group
   //
@@ -234,8 +276,9 @@ MainObject::MainObject(QObject *parent,const char *name)
   // Get Audio Parameters
   //
   RDLibraryConf *library_conf=new RDLibraryConf(import_config->stationName(),0);
+  import_system=new RDSystem();
   import_format=library_conf->defaultFormat();
-  import_samprate=library_conf->defaultSampleRate();
+  import_samprate=import_system->sampleRate();
   import_bitrate=library_conf->defaultBitrate();
   import_channels=library_conf->defaultChannels();
   import_normalization_level=library_conf->ripperLevel();
@@ -374,6 +417,14 @@ MainObject::MainObject(QObject *parent,const char *name)
     else {
       printf(" Broken format workarounds are DISABLED\n");
     }
+    if(import_create_dates) {
+      printf(" Import Create Dates mode is ON\n");
+      printf(" Import Create Start Date Offset = %d days\n",import_create_startdate_offset);
+      printf(" Import Create End Date Offset = %d days\n",import_create_enddate_offset);
+    }
+    else {
+      printf(" Import Create Dates mode is OFF\n");
+    }
     if(import_persistent_dropbox_id>=0) {
       printf(" Persistent DropBox ID = %d\n",import_persistent_dropbox_id);
     }
@@ -391,6 +442,28 @@ MainObject::MainObject(QObject *parent,const char *name)
   ::signal(SIGTERM,SigHandler);
   ::signal(SIGINT,SigHandler);
   ::signal(SIGHUP,SigHandler);
+}
+
+
+void MainObject::userData()
+{
+  //
+  // Get User Context
+  //
+  disconnect(import_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
+  if(import_user!=NULL) {
+    delete import_user;
+  }
+  import_user=new RDUser(import_ripc->user());
+
+  //
+  // Verify Permissions
+  //
+  if(!import_user->editAudio()) {
+    fprintf(stderr,"rdimport: user \"%s\" has no edit audio permission\n",
+	    (const char *)import_user->name());
+    exit(256);
+  }
 
   //
   // Process Files
@@ -462,6 +535,15 @@ MainObject::MainObject(QObject *parent,const char *name)
 
 void MainObject::RunDropBox()
 {
+  //
+  // Set Process Priority
+  //
+  struct sched_param sp;
+  memset(&sp,0,sizeof(sp));
+  if(sched_setscheduler(getpid(),SCHED_BATCH,&sp)!=0) {
+    printf(" Unable to set batch permissions, %s",strerror(errno));
+  }
+
   do {
     //
     // Clear the Checked Flag
@@ -555,7 +637,6 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 					  unsigned *cartnum)
 {
   bool cart_created=false;
-  unsigned length_deviation=0;
   QString effective_filename;
   bool found_cart=false;
   QDateTime dt;
@@ -691,55 +772,28 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
     cart_created=true;
   }
   int cutnum=
-    cart->addCut(import_format,import_samprate,import_bitrate,import_channels);
+    cart->addCut(import_format,import_bitrate,import_channels);
   RDCut *cut=new RDCut(QString().sprintf("%06u_%03d",*cartnum,cutnum));
+  RDAudioImport *conv=new RDAudioImport(import_station,this);
+  conv->setCartNumber(cart->number());
+  conv->setCutNumber(cutnum);
+  conv->setSourceFile(wavefile->getName());
+  RDSettings *settings=new RDSettings();
+  settings->setChannels(import_channels);
+  switch(import_format) {
+  case 0:
+    settings->setFormat(RDSettings::Pcm16);
+    break;
 
-  int format_in=0;
-  switch(wavefile->getFormatTag()) {
-      case WAVE_FORMAT_PCM:
-	format_in=0;
-	break;
+  case 1:
+    settings->setFormat(RDSettings::MpegL2Wav);
+    break;
+  }
+  settings->setNormalizationLevel(import_normalization_level/100);
+  settings->setAutotrimLevel(import_autotrim_level/100);
+  conv->setDestinationSettings(settings);
+  conv->setUseMetadata(cart_created);
 
-      case WAVE_FORMAT_MPEG:
-	format_in=wavefile->getHeadLayer();
-	break;
-  }
-  QString tempname=tempnam(NULL,RDIMPORT_TEMP_BASENAME);
-  QString tempwav_name=tempname+".wav";
-  QString tempdat_name=tempname+".dat";
-  double normal=pow(10.0,(double)import_normalization_level/2000.0);
-  QString cmd;
-  if(import_normalization_level==0) {
-    cmd=QString().
-      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s %s %d",
-	      format_in,
-	      wavefile->getSamplesPerSec(),
-	      (const char *)RDEscapeString(effective_filename).utf8(),  
-	      import_format,
-	      import_channels,
-	      import_samprate,
-	      import_channels*import_bitrate/1000,
-	      RDCut::pathName(cut->cutName()).ascii(), 
-	      (const char *)tempdat_name,
-	      (const char *)tempwav_name,
-	      import_src_converter);
-  }
-  else {
-    cmd=QString().
-      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s %d",
-	      normal,
-	      format_in,
-	      wavefile->getSamplesPerSec(),
-	      (const char *)RDEscapeString(effective_filename).utf8(),  
-	      import_format,
-	      import_channels,
-	      import_samprate,
-	      import_channels*import_bitrate/1000,
-	      RDCut::pathName(cut->cutName()).ascii(), 
-	      (const char *)tempdat_name,
-	      (const char *)tempwav_name,
-	      import_src_converter);
-  }
   if(import_verbose) {
     PrintLogDateTime();
     if(wavedata->title().length()==0 || ( (wavedata->title().length()>0) && (wavedata->title()[0] == '\0')) ) {
@@ -753,20 +807,17 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
     }
     fflush(stdout);
   }
-  if(system((const char *)cmd.utf8())==0) {
-    chown(RDCut::pathName(cut->cutName()),import_config->uid(),
-	  import_config->gid());
-    chmod(RDCut::pathName(cut->cutName()),
-	  S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH);
-  }
-  else {
+
+  switch(conv->runImport(import_user->name(),import_user->password())) {
+  case RDAudioImport::ErrorOk:
+    break;
+
+  default:
     PrintLogDateTime(stderr);
     fprintf(stderr," Unable to import \"%s\", skipping...\n",
 	    (const char *)filename.utf8());
     fflush(stderr);
-    cart->remove();
-    unlink(tempwav_name);
-    unlink(tempdat_name);
+    cart->remove(import_station,import_user);
     delete cut;
     delete cart;
     wavefile->closeWave();
@@ -781,16 +832,18 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
       import_temp_fix_filename="";
     }
     return MainObject::FileBad;
+    break;
   }
-  cut->reset();
-  cut->setOriginName(import_config->stationName());
   if(wavedata->metadataFound()) {
+    if(import_autotrim_level!=0) {
+      wavedata->setStartPos(-1);
+      wavedata->setEndPos(-1);
+    }
     if(cart_created) {
       cart->setMetadata(wavedata);
     }
     cut->setMetadata(wavedata);
   }
-  cut->autoTrim(RDCut::AudioBoth,import_autotrim_level);
   cut->autoSegue(import_segue_level,import_segue_length);
   if((wavedata->title().length()==0)||
      ((wavedata->title().length()>0)&&(wavedata->title()[0] == '\0'))) {
@@ -813,10 +866,6 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
       cart->setTitle(wavedata->cutId());
     }
   }
-  cart->updateLength();
-  cart->resetRotation();
-  cart->calculateAverageLength(&length_deviation);
-  cart->setLengthDeviation(length_deviation);
   if(import_startdate_offset!=0) {
     dt=cut->startDatetime(&ok);
     if(ok) {
@@ -829,12 +878,20 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
       cut->setEndDatetime(dt.addDays(import_enddate_offset),true);
     }
   }
-  if(import_verbose) {
-    printf("done.\n");
-    fflush(stdout);
+  if (import_create_dates)  {
+    dt=cut->startDatetime(&ok);
+    if (!ok){
+      dt=QDateTime(QDate::currentDate(), QTime(0,0,0));
+      cut->setStartDatetime(dt.addDays(import_create_startdate_offset),true);
+    }
+    dt=cut->endDatetime(&ok);
+    if(!ok) {
+      dt=QDateTime(QDate::currentDate(), QTime(23,59,59));
+      cut->setEndDatetime(dt.addDays(import_create_enddate_offset),true);
+    }
   }
-  unlink(tempwav_name);
-  unlink(tempdat_name);
+  delete settings;
+  delete conv;
   delete cut;
   delete cart;
   wavefile->closeWave();
@@ -1304,7 +1361,7 @@ void MainObject::DeleteCuts(unsigned cartnum)
   }
   unsigned dev;
   RDCart *cart=new RDCart(cartnum);
-  cart->removeAllCuts();
+  cart->removeAllCuts(import_station,import_user);
   cart->updateLength();
   cart->resetRotation();
   cart->calculateAverageLength(&dev);
